@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: error.c 3216 2007-02-24 15:23:38Z roms $ */
+/* $Id: error.c 3056 2006-11-06 17:12:50Z roms $ */
 
 /*  libtifiles - file format library, a part of the TiLP project
  *  Copyright (C) 1999-2005  Romain Lievin
@@ -56,7 +56,7 @@ TIEXPORT2 int TICALL tifiles_error_get(FileError number, char **message)
 		*message = g_strconcat(
 			_("Msg: unable to open file."),
 			"\n",
-			_("Cause: either the file does not exist, either there is no room."),
+			_("either the file does not exist, either there is no room."),
 			NULL);
     break;
 
@@ -78,7 +78,7 @@ TIEXPORT2 int TICALL tifiles_error_get(FileError number, char **message)
 
 	case ERR_BAD_CALC:
 		*message = g_strconcat(
-			_("Msg: unknown calculator type."),
+			_("Msg: Unknown calculator type."),
 			"\n",
 			_("Cause: probably due to a bug, mail to: tilp-users@lists.sf.net."),
 			NULL);
