@@ -1,4 +1,4 @@
-/* $Id: files8x.c 3524 2007-06-26 13:31:26Z roms $ */
+/* $Id: files8x.c 3056 2006-11-06 17:12:50Z roms $ */
 
 /*  libtifiles - file format library, a part of the TiLP project
  *  Copyright (C) 1999-2005  Romain Lievin
@@ -123,7 +123,7 @@ int ti8x_file_read_regular(const char *filename, Ti8xRegular *content)
   f = gfopen(filename, "rb");
   if (f == NULL) 
   {
-    tifiles_warning( "Unable to open this file: %s\n", filename);
+    tifiles_warning( "Unable to open this file: <%s>\n", filename);
     return ERR_FILE_OPEN;
   }
 
@@ -191,7 +191,7 @@ int ti8x_file_read_regular(const char *filename, Ti8xRegular *content)
   if(fseek(f, offset, SEEK_SET) < 0) goto tfrr;
 
   content->num_entries = i;
-  content->entries = g_malloc0((content->num_entries + 1) * sizeof(VarEntry*));
+  content->entries = calloc(content->num_entries + 1, sizeof(VarEntry*));
   if (content->entries == NULL) 
   {
     fclose(f);
@@ -200,7 +200,7 @@ int ti8x_file_read_regular(const char *filename, Ti8xRegular *content)
 
   for (i = 0; i < content->num_entries; i++) 
   {
-    VarEntry *entry = content->entries[i] = g_malloc0(sizeof(VarEntry));
+    VarEntry *entry = content->entries[i] = calloc(1, sizeof(VarEntry));
 	uint16_t packet_length, entry_size;
 
     if(fread_word(f, &packet_length) < 0) goto tfrr;
@@ -210,7 +210,7 @@ int ti8x_file_read_regular(const char *filename, Ti8xRegular *content)
     if (is_ti8586(content->model))
       if(fread_byte(f, &name_length) < 0) goto tfrr;
     if(fread_n_chars(f, name_length, varname) < 0) goto tfrr;
-	ticonv_varname_from_tifile_s(content->model_dst, varname, entry->name, entry->type);
+	ticonv_varname_from_tifile_s(content->model_dst, varname, entry->name);
 	if((content->model == CALC_TI86) && padded86)
 	{
 		for(j = 0; j < 8-name_length; j++)
@@ -223,7 +223,7 @@ int ti8x_file_read_regular(const char *filename, Ti8xRegular *content)
     }
     if(fread_word(f, NULL) < 0) goto tfrr;
 
-    entry->data = (uint8_t *) g_malloc0(entry->size);
+    entry->data = (uint8_t *) calloc(entry->size, 1);
     if (entry->data == NULL) 
 	{
       fclose(f);
@@ -282,7 +282,7 @@ int ti8x_file_read_backup(const char *filename, Ti8xBackup *content)
   f = gfopen(filename, "rb");
   if (f == NULL) 
   {
-    tifiles_info( "Unable to open this file: %s", filename);
+    tifiles_info( "Unable to open this file: <%s>", filename);
     return ERR_FILE_OPEN;
   }
 
@@ -306,7 +306,7 @@ int ti8x_file_read_backup(const char *filename, Ti8xBackup *content)
 	{ if(fread_word(f, &(content->data_length4)) < 0) goto tfrb;}
 
   if(fread_word(f, NULL) < 0) goto tfrb;
-  content->data_part1 = (uint8_t *)g_malloc0(content->data_length1);
+  content->data_part1 = (uint8_t *) calloc(content->data_length1, 1);
   if (content->data_part1 == NULL) 
   {
     fclose(f);
@@ -315,7 +315,7 @@ int ti8x_file_read_backup(const char *filename, Ti8xBackup *content)
   if(fread(content->data_part1, 1, content->data_length1, f) < content->data_length1) goto tfrb;
 
   if(fread_word(f, NULL) < 0) goto tfrb;
-  content->data_part2 = (uint8_t *)g_malloc0(content->data_length2);
+  content->data_part2 = (uint8_t *) calloc(content->data_length2, 1);
   if (content->data_part2 == NULL) 
   {
     fclose(f);
@@ -326,7 +326,7 @@ int ti8x_file_read_backup(const char *filename, Ti8xBackup *content)
   if (content->data_length3)	// can be 0000 on TI86
   {
     if(fread_word(f, NULL) < 0) goto tfrb;
-    content->data_part3 = (uint8_t *)g_malloc0(content->data_length3);
+    content->data_part3 = (uint8_t *) calloc(content->data_length3, 1);
     if (content->data_part3 == NULL) 
 	{
       fclose(f);
@@ -338,7 +338,7 @@ int ti8x_file_read_backup(const char *filename, Ti8xBackup *content)
   if (content->model == CALC_TI86) 
   {
     if(fread_word(f, NULL) < 0) goto tfrb;
-    content->data_part4 = (uint8_t *)g_malloc0(content->data_length4);
+    content->data_part4 = (uint8_t *) calloc(content->data_length4, 1);
     if (content->data_part4 == NULL) 
 	{
       fclose(f);
@@ -382,7 +382,7 @@ static int check_device_type(uint8_t id)
 
 static int check_data_type(uint8_t id)
 {
-	const uint8_t types[] = { 0, TI83p_AMS, TI83p_APPL, TI83p_CERT, TI83p_LICENSE  };
+	const uint8_t types[] = { 0, TI83p_AMS, TI83p_APPL, TI83p_CERTIF, TI83p_LICENSE  };
 	int i;
 
 	for(i = 1; i <= sizeof(types)/sizeof(uint8_t); i++)
@@ -417,7 +417,7 @@ int ti8x_file_read_flash(const char *filename, Ti8xFlash *head)
   f = gfopen(filename, "rb");
   if (f == NULL) 
   {
-    tifiles_info("Unable to open this file: %s", filename);
+    tifiles_info("Unable to open this file: <%s>", filename);
     return ERR_FILE_OPEN;
   }
 
@@ -445,10 +445,10 @@ int ti8x_file_read_flash(const char *filename, Ti8xFlash *head)
 	  if(!check_data_type(content->data_type))
 				return ERR_INVALID_FILE;
 
-	  if(content->data_type == TI83p_CERT || content->data_type == TI83p_LICENSE)
+	  if(content->data_type == TI83p_CERTIF || content->data_type == TI83p_LICENSE)
 	  {
 		  // get data like TI9X
-		  content->data_part = (uint8_t *)g_malloc0(content->data_length + 256);
+		  content->data_part = (uint8_t *) calloc(content->data_length + 256, 1);
 		  if (content->data_part == NULL) 
 		  {
 			fclose(f);
@@ -467,7 +467,7 @@ int ti8x_file_read_flash(const char *filename, Ti8xFlash *head)
 		  content->pages = NULL;
 
 		  // we should determine the number of pages, to do...
-		  content->pages = g_malloc0((50+1) * sizeof(Ti8xFlashPage *));
+		  content->pages = calloc(50+1, sizeof(Ti8xFlashPage *));
 		  if (content->pages == NULL)
 			return ERR_MALLOC;
 
@@ -480,11 +480,11 @@ int ti8x_file_read_flash(const char *filename, Ti8xFlash *head)
 				uint16_t page;
 				uint8_t flag = 0x80;
 				uint8_t data[PAGE_SIZE];
-				FlashPage* fp = content->pages[i] = g_malloc0(sizeof(FlashPage));
+				FlashPage* fp = content->pages[i] = calloc(1, sizeof(FlashPage));
 
 				ret = hex_block_read(f, &size, &addr, &flag, data, &page);
 
-				fp->data = (uint8_t *) g_malloc0(PAGE_SIZE);
+				fp->data = (uint8_t *) calloc(PAGE_SIZE, 1);
 				memset(fp->data, 0xff, PAGE_SIZE);
 				if (fp->data == NULL)
 					return ERR_MALLOC;
@@ -508,7 +508,7 @@ int ti8x_file_read_flash(const char *filename, Ti8xFlash *head)
 			break;
 		if(fseek(f, -8, SEEK_CUR)) goto tfrf;
 
-		content->next = (Ti8xFlash *)g_malloc0(sizeof(Ti8xFlash));
+		content->next = (Ti8xFlash *) calloc(1, sizeof(Ti8xFlash));
 		if (content->next == NULL) 
 		{
 			fclose(f);
@@ -555,7 +555,7 @@ int ti8x_file_write_regular(const char *fname, Ti8xRegular *content, char **real
 
   if (fname != NULL) 
   {
-    filename = g_strdup(fname);
+    filename = strdup(fname);
     if (filename == NULL)
       return ERR_MALLOC;
   } 
@@ -563,17 +563,17 @@ int ti8x_file_write_regular(const char *fname, Ti8xRegular *content, char **real
   {
 	filename = tifiles_build_filename(content->model_dst, content->entries[0]);
 	if (real_fname != NULL)
-      *real_fname = g_strdup(filename);
+      *real_fname = strdup(filename);
   }
 
   f = gfopen(filename, "wb");
   if (f == NULL) 
   {
-    tifiles_info( "Unable to open this file: %s", filename);
-    g_free(filename);
+    tifiles_info( "Unable to open this file: <%s>", filename);
+    free(filename);
     return ERR_FILE_OPEN;
   }
-  g_free(filename);
+  free(filename);
 
   // write header
   if(fwrite_8_chars(f, tifiles_calctype2signature(content->model)) < 0) goto tfwr;
@@ -631,7 +631,7 @@ int ti8x_file_write_regular(const char *fname, Ti8xRegular *content, char **real
     if(fwrite_word(f, (uint16_t)entry->size) < 0) goto tfwr;
     if(fwrite_byte(f, entry->type) < 0) goto tfwr;
 	memset(varname, 0, sizeof(varname));
-	ticonv_varname_to_tifile_s(content->model_dst, entry->name, varname, entry->type);
+	ticonv_varname_to_tifile_s(content->model_dst, entry->name, varname);
     if (is_ti8586(content->model)) 
 	{
       name_length = strlen(varname);
@@ -691,7 +691,7 @@ int ti8x_file_write_backup(const char *filename, Ti8xBackup *content)
   f = gfopen(filename, "wb");
   if (f == NULL) 
   {
-    tifiles_info( "Unable to open this file: %s", filename);
+    tifiles_info( "Unable to open this file: <%s>", filename);
     return ERR_FILE_OPEN;
   }
   // write header
@@ -761,7 +761,7 @@ int ti8x_file_write_flash(const char *fname, Ti8xFlash *head, char **real_fname)
 
   if (fname)
   {
-	  filename = g_strdup(fname);
+	  filename = strdup(fname);
 	  if(filename == NULL)
 		  return ERR_MALLOC;
   }
@@ -778,13 +778,13 @@ int ti8x_file_write_flash(const char *fname, Ti8xFlash *head, char **real_fname)
 
 	  filename = tifiles_build_filename(content->model, &ve);
 	  if (real_fname != NULL)
-		*real_fname = g_strdup(filename);
+		*real_fname = strdup(filename);
   }
 
   f = gfopen(filename, "wb");
   if (f == NULL) 
   {
-    tifiles_info("Unable to open this file: %s", filename);
+    tifiles_info("Unable to open this file: <%s>", filename);
     return ERR_FILE_OPEN;
   }
   
@@ -810,7 +810,7 @@ int ti8x_file_write_flash(const char *fname, Ti8xFlash *head, char **real_fname)
     if(fwrite_long(f, content->data_length) < 0) goto tfwf;
 
 	// data
-	if(content->data_type == TI83p_CERT || content->data_type == TI83p_LICENSE)
+	if(content->data_type == TI83p_CERTIF || content->data_type == TI83p_LICENSE)
 	{
 		if(fwrite(content->data_part, 1, content->data_length, f) < content->data_length) goto tfwf;
 	}
@@ -865,17 +865,16 @@ int ti8x_content_display_regular(Ti8xRegular *content)
   int i;
   char trans[17];
 
-  tifiles_info("Signature:     %s",
+  tifiles_info("Signature:     <%s>",
 	  tifiles_calctype2signature(content->model));
-  tifiles_info("Comment:       %s", content->comment);
+  tifiles_info("Comment:       <%s>", content->comment);
   tifiles_info("# of entries:  %i", content->num_entries);
 
   for (i = 0; i < content->num_entries /*&& i<5 */ ; i++) 
   {
     tifiles_info("Entry #%i", i);
-    tifiles_info("  name:        %s",
-		ticonv_varname_to_utf8_s(content->model, content->entries[i]->name, 
-			trans, content->entries[i]->type));
+    tifiles_info("  name:        <%s>",
+		ticonv_varname_to_utf8_s(content->model, content->entries[i]->name, trans));
     tifiles_info("  type:        %02X (%s)",
 	    content->entries[i]->type,
 	    tifiles_vartype2string(content->model, content->entries[i]->type));
@@ -901,9 +900,9 @@ int ti8x_content_display_regular(Ti8xRegular *content)
  **/
 int ti8x_content_display_backup(Ti8xBackup *content)
 {
-  tifiles_info("Signature:      %s",
+  tifiles_info("Signature:      <%s>",
 	  tifiles_calctype2signature(content->model));
-  tifiles_info("Comment:        %s", content->comment);
+  tifiles_info("Comment:        <%s>", content->comment);
   tifiles_info("Type:           %02X (%s)", content->type,
 	  tifiles_vartype2string(content->model, content->type));
   tifiles_info("Mem address:    %04X (%i)",
@@ -941,7 +940,7 @@ int ti8x_content_display_flash(Ti8xFlash *content)
 
   for (ptr = content; ptr != NULL; ptr = ptr->next) 
   {
-	  tifiles_info("Signature:       %s",
+	  tifiles_info("Signature:       <%s>",
 		  tifiles_calctype2signature(ptr->model));
 	  tifiles_info("Revision:        %i.%i", ptr->revision_major,
 		  ptr->revision_minor);
@@ -950,7 +949,7 @@ int ti8x_content_display_flash(Ti8xFlash *content)
 	  tifiles_info("Date:            %02X/%02X/%02X%02X",
 		  ptr->revision_day, ptr->revision_month,
 		  ptr->revision_year&0xff, (ptr->revision_year&0xff00) >> 8);
-	  tifiles_info("Name:            %s", ptr->name);
+	  tifiles_info("Name:            <%s>", ptr->name);
 	  tifiles_info("Device type:     %s",
 		  ptr->device_type == DEVICE_TYPE_83P ? "ti83+" : "ti73");
 	  tifiles_info("Data type:       ");
