@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: files9x.c 3524 2007-06-26 13:31:26Z roms $ */
+/* $Id: files9x.c 3079 2006-11-14 18:22:30Z kevinkofler $ */
 
 /*  libtifiles - file format library, a part of the TiLP project
  *  Copyright (C) 1999-2005  Romain Lievin
@@ -82,7 +82,7 @@ int ti9x_file_read_regular(const char *filename, Ti9xRegular *content)
   f = gfopen(filename, "rb");
   if (f == NULL) 
   {
-    tifiles_info( "Unable to open this file: %s", filename);
+    tifiles_info( "Unable to open this file: <%s>", filename);
     return ERR_FILE_OPEN;
   }
 
@@ -94,13 +94,13 @@ int ti9x_file_read_regular(const char *filename, Ti9xRegular *content)
 
   if(fread_word(f, NULL) < 0) goto tffr;
   if(fread_8_chars(f, default_folder) < 0) goto tffr;
-  ticonv_varname_from_tifile_s(content->model_dst, default_folder, content->default_folder, -1);
+  ticonv_varname_from_tifile_s(content->model_dst, default_folder, content->default_folder);
   strcpy(current_folder, content->default_folder);
   if(fread_n_chars(f, 40, content->comment) < 0) goto tffr;
   if(fread_word(f, &tmp) < 0) goto tffr;
   content->num_entries = tmp;
 
-  content->entries = g_malloc0((content->num_entries + 1) * sizeof(VarEntry*));
+  content->entries = calloc(content->num_entries + 1, sizeof(VarEntry*));
   if (content->entries == NULL) 
   {
     fclose(f);
@@ -109,11 +109,11 @@ int ti9x_file_read_regular(const char *filename, Ti9xRegular *content)
 
   for (i = 0, j = 0; i < content->num_entries; i++) 
   {
-    VarEntry *entry = content->entries[j] = g_malloc0(sizeof(VarEntry));
+    VarEntry *entry = content->entries[j] = calloc(1, sizeof(VarEntry));
 
     if(fread_long(f, &curr_offset) < 0) goto tffr;
     if(fread_8_chars(f, varname) < 0)  goto tffr;
-	ticonv_varname_from_tifile_s(content->model_dst, varname, entry->name, entry->type);
+	ticonv_varname_from_tifile_s(content->model_dst, varname, entry->name);
     if(fread_byte(f, &(entry->type)) < 0) goto tffr;
     if(fread_byte(f, &(entry->attr)) < 0) goto tffr;
     entry->attr = (entry->attr == 2 || entry->attr == 3) ? ATTRB_ARCHIVED : entry->attr;
@@ -122,7 +122,7 @@ int ti9x_file_read_regular(const char *filename, Ti9xRegular *content)
     if (entry->type == TI92_DIR) // same as TI89_DIR, TI89t_DIR, ...
 	{
       strcpy(current_folder, entry->name);
-      g_free(entry);
+      free(entry);
       continue;			// folder: skip entry
     } 
 	else 
@@ -135,7 +135,7 @@ int ti9x_file_read_regular(const char *filename, Ti9xRegular *content)
 	  if(cur_pos == -1L) goto tffr;
       if(fread_long(f, &next_offset) < 0) goto tffr;
       entry->size = next_offset - curr_offset - 4 - 2;
-      entry->data = (uint8_t *)g_malloc0(entry->size);
+      entry->data = (uint8_t *) calloc(entry->size, 1);
       if (entry->data == NULL) 
 	  {
 		fclose(f);
@@ -200,7 +200,7 @@ int ti9x_file_read_backup(const char *filename, Ti9xBackup *content)
   f = gfopen(filename, "rb");
   if (f == NULL) 
   {
-    tifiles_info( "Unable to open this file: %s", filename);
+    tifiles_info( "Unable to open this file: <%s>", filename);
     return ERR_FILE_OPEN;
   }
 
@@ -222,7 +222,7 @@ int ti9x_file_read_backup(const char *filename, Ti9xBackup *content)
   content->data_length = file_size - 0x52 - 2;
   if(fread_word(f, NULL) < 0) goto tfrb;
 
-  content->data_part = (uint8_t *)g_malloc0(content->data_length);
+  content->data_part = (uint8_t *) calloc(content->data_length, 1);
   if (content->data_part == NULL) 
   {
     fclose(f);
@@ -304,7 +304,7 @@ int ti9x_file_read_flash(const char *filename, Ti9xFlash *head)
 	f = gfopen(filename, "rb");
 	if (f == NULL) 
 	{
-	    tifiles_info("Unable to open this file: %s\n", filename);
+	    tifiles_info("Unable to open this file: <%s>\n", filename);
 		return ERR_FILE_OPEN;
 	}  
 
@@ -318,7 +318,7 @@ int ti9x_file_read_flash(const char *filename, Ti9xFlash *head)
 		strcpy(content->name, "basecode");
 		content->data_type = 0x23;	// FLASH os
 
-		content->data_part = (uint8_t *)g_malloc0(content->data_length);
+		content->data_part = (uint8_t *) calloc(content->data_length, 1);
 		if (content->data_part == NULL) 
 		{
 			fclose(f);
@@ -365,7 +365,7 @@ int ti9x_file_read_flash(const char *filename, Ti9xFlash *head)
 			if(!check_data_type(content->data_type))
 				return ERR_INVALID_FILE;
 
-			content->data_part = (uint8_t *)g_malloc0(content->data_length);
+			content->data_part = (uint8_t *) calloc(content->data_length, 1);
 			if (content->data_part == NULL) 
 			{
 				fclose(f);
@@ -383,7 +383,7 @@ int ti9x_file_read_flash(const char *filename, Ti9xFlash *head)
 				break;
 			if(fseek(f, -8, SEEK_CUR)) goto tfrf;
 
-			content->next = (Ti9xFlash *)g_malloc0(sizeof(Ti9xFlash));
+			content->next = (Ti9xFlash *) calloc(1, sizeof(Ti9xFlash));
 			if (content->next == NULL) 
 			{
 				fclose(f);
@@ -433,7 +433,7 @@ int ti9x_file_write_regular(const char *fname, Ti9xRegular *content, char **real
 
   if (fname != NULL) 
   {
-    filename = g_strdup(fname);
+    filename = strdup(fname);
     if (filename == NULL)
       return ERR_MALLOC;
   } 
@@ -441,17 +441,17 @@ int ti9x_file_write_regular(const char *fname, Ti9xRegular *content, char **real
   {
 	filename = tifiles_build_filename(content->model_dst, content->entries[0]);
 	if (real_fname != NULL)
-      *real_fname = g_strdup(filename);
+      *real_fname = strdup(filename);
   }
 
   f = gfopen(filename, "wb");
   if (f == NULL) 
   {
-    tifiles_info( "Unable to open this file: %s", filename);
-    g_free(filename);
+    tifiles_info( "Unable to open this file: <%s>", filename);
+    free(filename);
     return ERR_FILE_OPEN;
   }
-  g_free(filename);
+  free(filename);
 
   // build the table of folder & variable entries  
   table = tifiles_create_table_of_entries((FileContent *)content, &num_folders);
@@ -463,7 +463,7 @@ int ti9x_file_write_regular(const char *fname, Ti9xRegular *content, char **real
   if(fwrite(fsignature, 1, 2, f) < 2) goto tfwr;
   if (content->num_entries == 1)	// folder entry for single var is placed here
     strcpy(content->default_folder, content->entries[0]->folder);
-  ticonv_varname_to_tifile_s(content->model, content->default_folder, default_folder, -1);
+  ticonv_varname_to_tifile_s(content->model, content->default_folder, default_folder);
   if(fwrite_8_chars(f, default_folder) < 0) goto tfwr;
   if(fwrite_n_bytes(f, 40, (uint8_t *)content->comment) < 0) goto tfwr;
   if (content->num_entries > 1) 
@@ -484,7 +484,7 @@ int ti9x_file_write_regular(const char *fname, Ti9xRegular *content, char **real
     if (content->num_entries > 1)	// single var does not have folder entry
     {
       if(fwrite_long(f, offset) < 0) goto tfwr;
-	  ticonv_varname_to_tifile_s(content->model, fentry->folder, fldname, -1);
+	  ticonv_varname_to_tifile_s(content->model, fentry->folder, fldname);
       if(fwrite_8_chars(f, fldname) < 0) goto tfwr;
       if(fwrite_byte(f, (uint8_t)tifiles_folder_type(content->model)) < 0) goto tfwr;
       if(fwrite_byte(f, 0x00) < 0) goto tfwr;
@@ -499,7 +499,7 @@ int ti9x_file_write_regular(const char *fname, Ti9xRegular *content, char **real
 	  uint8_t attr = ATTRB_NONE;
 
       if(fwrite_long(f, offset) < 0) goto tfwr;
-	  ticonv_varname_to_tifile_s(content->model, entry->name, varname, entry->type);
+	  ticonv_varname_to_tifile_s(content->model, entry->name, varname);
       if(fwrite_8_chars(f, varname) < 0) goto tfwr;
       if(fwrite_byte(f, entry->type) < 0) goto tfwr;
       attr = (entry->attr == ATTRB_ARCHIVED) ? 3 : entry->attr;
@@ -531,10 +531,10 @@ int ti9x_file_write_regular(const char *fname, Ti9xRegular *content, char **real
     }
   }
 
-  // g_free( memory
+  // free memory
   for (i = 0; i < num_folders; i++)
-    g_free(table[i]);
-  g_free(table);
+    free(table[i]);
+  free(table);
 
   fclose(f);
   return 0;
@@ -560,7 +560,7 @@ int ti9x_file_write_backup(const char *filename, Ti9xBackup *content)
   f = gfopen(filename, "wb");
   if (f == NULL) 
   {
-    tifiles_info("Unable to open this file: %s", filename);
+    tifiles_info("Unable to open this file: <%s>", filename);
     return ERR_FILE_OPEN;
   }
 
@@ -606,7 +606,7 @@ int ti9x_file_write_flash(const char *fname, Ti9xFlash *head, char **real_fname)
 
   if (fname)
   {
-	  filename = g_strdup(fname);
+	  filename = strdup(fname);
 	  if(filename == NULL)
 		  return ERR_MALLOC;
   }
@@ -623,13 +623,13 @@ int ti9x_file_write_flash(const char *fname, Ti9xFlash *head, char **real_fname)
 
 	  filename = tifiles_build_filename(content->model, &ve);
 	  if (real_fname != NULL)
-		*real_fname = g_strdup(filename);
+		*real_fname = strdup(filename);
   }
 
   f = gfopen(filename, "wb");
   if (f == NULL) 
   {
-    tifiles_info("Unable to open this file: %s", filename);
+    tifiles_info("Unable to open this file: <%s>", filename);
     return ERR_FILE_OPEN;
   }
 
@@ -679,19 +679,18 @@ int ti9x_content_display_regular(Ti9xRegular *content)
   int i;
   char trans[17];
 
-  tifiles_info("Signature:         %s",
+  tifiles_info("Signature:         <%s>",
 	  tifiles_calctype2signature(content->model));
-  tifiles_info("Comment:           %s", content->comment);
-  tifiles_info("Default folder:    %s", content->default_folder);
+  tifiles_info("Comment:           <%s>", content->comment);
+  tifiles_info("Default folder:    <%s>", content->default_folder);
   tifiles_info("Number of entries: %i", content->num_entries);
 
   for (i = 0; i < content->num_entries /*&& i<5 */ ; i++) 
   {
     tifiles_info("Entry #%i", i);
-    tifiles_info("  folder:    %s", content->entries[i]->folder);
-    tifiles_info("  name:      %s",
-	    ticonv_varname_to_utf8_s(content->model, content->entries[i]->name, 
-			trans, content->entries[i]->type));
+    tifiles_info("  folder:    <%s>", content->entries[i]->folder);
+    tifiles_info("  name:      <%s>",
+	    ticonv_varname_to_utf8_s(content->model, content->entries[i]->name, trans));
     tifiles_info("  type:      %02X (%s)",
 	    content->entries[i]->type,
 	    tifiles_vartype2string(content->model, content->entries[i]->type));
@@ -717,10 +716,10 @@ int ti9x_content_display_regular(Ti9xRegular *content)
  **/
 int ti9x_content_display_backup(Ti9xBackup *content)
 {
-  tifiles_info("signature:      %s",
+  tifiles_info("signature:      <%s>",
 	  tifiles_calctype2signature(content->model));
-  tifiles_info("comment:        %s", content->comment);
-  tifiles_info("ROM version:    %s", content->rom_version);
+  tifiles_info("comment:        <%s>", content->comment);
+  tifiles_info("ROM version:    <%s>", content->rom_version);
   tifiles_info("type:           %02X (%s)",
 	  content->type, tifiles_vartype2string(content->model, content->type));
   tifiles_info("data length:    %08X (%i)",
@@ -746,7 +745,7 @@ int ti9x_content_display_flash(Ti9xFlash *content)
 
   for (ptr = content; ptr != NULL; ptr = ptr->next) 
   {
-    tifiles_info("Signature:      %s",
+    tifiles_info("Signature:      <%s>",
 	    tifiles_calctype2signature(ptr->model));
     tifiles_info("Revision:       %i.%i",
 	    ptr->revision_major, ptr->revision_minor);
@@ -755,7 +754,7 @@ int ti9x_content_display_flash(Ti9xFlash *content)
     tifiles_info("Date:           %02X/%02X/%02X%02X",
 	    ptr->revision_day, ptr->revision_month,
 	    ptr->revision_year & 0xff, (ptr->revision_year & 0xff00) >> 8);
-    tifiles_info("Name:           %s", ptr->name);
+    tifiles_info("Name:           <%s>", ptr->name);
     tifiles_info("Device type:    %s",
 	    ptr->device_type == DEVICE_TYPE_89 ? "ti89" : "ti92+");
     switch (ptr->data_type) 
