@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: files9x.h 3968 2007-11-01 20:14:10Z roms $ */
+/* $Id: files9x.h 3056 2006-11-06 17:12:50Z roms $ */
 
 /*  libtifiles - file format library, a part of the TiLP project
  *  Copyright (C) 1999-2005  Romain Lievin
@@ -19,8 +19,8 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#ifndef __TIFILES_FILES_9X_H__
-#define __TIFILES_FILES_9X_H__
+#ifndef __TIFILES_FILES9X_H__
+#define __TIFILES_FILES9X_H__
 
 #include "stdints2.h"
 #include "tifiles.h"
@@ -61,4 +61,6 @@ int ti9x_file_write_flash(const char *filename, Ti9xFlash *content, char **filen
 // displaying
 int ti9x_file_display(const char *filename);
 
+int** tifiles_create_table_of_entries(FileContent *content, int *nfolders);
+
 #endif
