@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: filesxx.c 3988 2007-11-07 15:03:20Z roms $ */
+/* $Id: filesxx.c 3056 2006-11-06 17:12:50Z roms $ */
 
 /*  libtifiles - file format library, a part of the TiLP project
  *  Copyright (C) 1999-2006  Romain Lievin
@@ -34,7 +34,6 @@
 #include "error.h"
 #include "files8x.h"
 #include "files9x.h"
-#include "filesnsp.h"
 
 /**
  * tifiles_content_create_regular:
@@ -46,7 +45,7 @@
  **/
 TIEXPORT2 FileContent* TICALL tifiles_content_create_regular(CalcModel model)
 {
-	FileContent* content = g_malloc0(sizeof(FileContent));
+	FileContent* content = calloc(1, sizeof(FileContent));
 
 	content->model = content->model_dst = model;
 	strcpy(content->comment, tifiles_comment_set_single());
@@ -72,12 +71,12 @@ TIEXPORT2 int TICALL tifiles_content_delete_regular(FileContent *content)
     VarEntry *entry = content->entries[i];
 
 	assert(entry != NULL);
-    g_free(entry->data);
-	g_free(entry);
+    free(entry->data);
+	free(entry);
   }
 
-  g_free(content->entries);
-  g_free(content);
+  free(content->entries);
+  free(content);
 
   return 0;
 }
@@ -130,10 +129,7 @@ TIEXPORT2 int tifiles_file_read_regular(const char *filename, FileContent *conte
 		return ti9x_file_read_regular(filename, (Ti9xRegular *)content);
 	else
 #endif
-    if(content->model == CALC_NSPIRE)
-		return tnsp_file_read_regular(filename, (FileContent *)content);
-	else
-		return ERR_BAD_CALC;
+    return ERR_BAD_CALC;
 
 	return 0;
 }
@@ -164,10 +160,7 @@ TIEXPORT2 int tifiles_file_write_regular(const char *filename, FileContent *cont
 		return ti9x_file_write_regular(filename, (Ti9xRegular *)content, real_fname);
 	else
 #endif
-	if(content->model == CALC_NSPIRE)
-		return tnsp_file_write_regular(filename, (FileContent *)content, real_fname);
-	else
-		return ERR_BAD_CALC;
+    return ERR_BAD_CALC;
 
 	return 0;
 }
@@ -192,10 +185,7 @@ TIEXPORT2 int TICALL tifiles_file_display_regular(FileContent *content)
 		return ti9x_content_display_regular(content);
 	else
 #endif
-	if(content->model == CALC_NSPIRE)
-		return tnsp_content_display_regular(content);
-	else
-		return ERR_BAD_CALC;
+    return ERR_BAD_CALC;
 
 	return 0;
 }
@@ -210,7 +200,7 @@ TIEXPORT2 int TICALL tifiles_file_display_regular(FileContent *content)
  **/
 TIEXPORT2 BackupContent* TICALL tifiles_content_create_backup(CalcModel model)
 {
-	BackupContent* content = g_malloc0(sizeof(BackupContent));
+	BackupContent* content = calloc(1, sizeof(BackupContent));
 
 	content->model = model;
 	strcpy(content->comment, tifiles_comment_set_backup());
@@ -230,16 +220,16 @@ TIEXPORT2 int TICALL tifiles_content_delete_backup(BackupContent *content)
   assert(content != NULL);
 
   if (tifiles_calc_is_ti9x(content->model))
-		g_free(content->data_part);
+		free(content->data_part);
   else if (tifiles_calc_is_ti8x(content->model))
   {
-	  g_free(content->data_part1);
-	  g_free(content->data_part2);
-	  g_free(content->data_part3);
-	  g_free(content->data_part4);
+	  free(content->data_part1);
+	  free(content->data_part2);
+	  free(content->data_part3);
+	  free(content->data_part4);
   }
 
-  g_free(content);
+  free(content);
 
   return 0;
 }
@@ -334,7 +324,7 @@ TIEXPORT2 int TICALL tifiles_file_display_backup(BackupContent *content)
  **/
 TIEXPORT2 FlashContent* TICALL tifiles_content_create_flash(CalcModel model)
 {
-	FlashContent* content = g_malloc0(sizeof(FlashContent));
+	FlashContent* content = calloc(1, sizeof(FlashContent));
 
 	content->model = model;
 	if(tifiles_calc_is_ti9x(content->model))
@@ -372,27 +362,27 @@ TIEXPORT2 int TICALL tifiles_content_delete_flash(FlashContent *content)
 	{
 		FlashContent *ptr;
 
-		g_free(content->data_part);
+		free(content->data_part);
 
 		ptr = content->next;
 		while (ptr != NULL) 
 		{
 			FlashContent *next = ptr->next;
 
-			g_free(ptr->data_part);
-			g_free(ptr);
+			free(ptr->data_part);
+			free(ptr);
 
 			for(i = 0; i < content->num_pages; i++)
 			{
-				g_free(content->pages[i]->data);
-				g_free(content->pages[i]);
+				free(content->pages[i]->data);
+				free(content->pages[i]);
 			}
-			g_free(content->pages);
+			free(content->pages);
 
 			ptr = next;
 		}
 
-		g_free(content);
+		free(content);
 	}
 #else
     return ERR_BAD_CALC;
@@ -425,10 +415,7 @@ TIEXPORT2 int tifiles_file_read_flash(const char *filename, FlashContent *conten
 		return ti9x_file_read_flash(filename, content);
 	else
 #endif
-	if(content->model == CALC_NSPIRE)
-		return tnsp_file_read_flash(filename, content);
-	else
-		return ERR_BAD_CALC;
+    return ERR_BAD_CALC;
 
 	return 0;
 }
@@ -507,7 +494,7 @@ TIEXPORT2 FlashContent* TICALL tifiles_content_dup_flash(FlashContent *content)
 		{
 			if(p->data_part)
 			{
-				q->data_part = (uint8_t *)g_malloc0(p->data_length+1);
+				q->data_part = (uint8_t *)calloc(p->data_length+1, 1);
 				memcpy(q->data_part, p->data_part, p->data_length+1);
 			}
 		}
@@ -521,10 +508,10 @@ TIEXPORT2 FlashContent* TICALL tifiles_content_dup_flash(FlashContent *content)
 			q->pages = tifiles_fp_create_array(p->num_pages);	
 			for(i = 0; i < content->num_pages; i++)
 			{
-				q->pages[i] = (FlashPage *)g_malloc0(sizeof(FlashPage));
+				q->pages[i] = (FlashPage *)calloc(1, sizeof(FlashPage));
 				memcpy(q->pages[i], p->pages[i], sizeof(FlashPage));
 
-				q->pages[i]->data = (uint8_t *) g_malloc0(p->pages[i]->size);
+				q->pages[i]->data = (uint8_t *) calloc(1, p->pages[i]->size);
 				memcpy(q->pages[i]->data, p->pages[i]->data, p->pages[i]->size);
 			}
 		}
@@ -614,7 +601,7 @@ TIEXPORT2 int TICALL tifiles_file_display(const char *filename)
  * Return value: a 2-dimensions allocated integer array. Must be freed when no
  * longer used.
  **/
-TIEXPORT2 int** tifiles_create_table_of_entries(FileContent *content, int *nfolders)
+int** tifiles_create_table_of_entries(FileContent *content, int *nfolders)
 {
   int num_folders = 0;
   int i, j;
@@ -631,13 +618,13 @@ TIEXPORT2 int** tifiles_create_table_of_entries(FileContent *content, int *nfold
 	{
       if (!strcmp(*ptr, entry->folder)) 
 	  {
-		//printf("break: %s\n", entry->folder);
+		//printf("break: <%s>\n", entry->folder);
 		break;
       }
     }
     if (*ptr == NULL) 
 	{		// add new folder entry
-      folder_list[num_folders] = (char *) g_malloc0(10);
+      folder_list[num_folders] = (char *) calloc(10, sizeof(char));
       //printf("%i: adding '%s'\n", num_folders, entry->folder);
       strcpy(folder_list[num_folders], entry->folder);
       folder_list[num_folders + 1] = NULL;
@@ -650,7 +637,7 @@ TIEXPORT2 int** tifiles_create_table_of_entries(FileContent *content, int *nfold
   *nfolders = num_folders;
 
   // allocate the folder list
-  table = (int **) g_malloc0((num_folders + 1) * sizeof(int *));
+  table = (int **) calloc((num_folders + 1), sizeof(int *));
   table[num_folders] = NULL;
 
   // for each folder, determine how many variables we have
@@ -674,9 +661,9 @@ TIEXPORT2 int** tifiles_create_table_of_entries(FileContent *content, int *nfold
     }
   }
 
-  // g_free( memory
+  // free memory
   for (j = 0; j < num_folders + 1; j++)
-    g_free(folder_list[j]);
+    free(folder_list[j]);
 
   return table;
 }
