@@ -35,44 +35,41 @@
 /* Global types */
 /****************/
 
-static const char GROUP_FILE_EXT[CALC_MAX + 1][4] = 
+#define NCALCS FILES_NCALCS
+
+static const char GROUP_FILE_EXT[NCALCS + 1][4] = 
 {
-	"XXx", 
+	"XxX", 
 	"73g", "82g", "83g", "8Xg", "8Xg", "85g", "86g", 
 	"89g", "89g", "92g", "9Xg", "V2g", "8Xg", "89g",
-	"XXx",
 };
 
-static const char BACKUP_FILE_EXT[CALC_MAX + 1][4] = 
+static const char BACKUP_FILE_EXT[NCALCS + 1][4] = 
 {
-	"XXx", 
+	"XxX", 
 	"73b", "82b", "83b", "8Xb", "8Xb", "85b", "86b", 
 	"89g", "89g", "92b", "9Xg", "V2g", "8Xg", "89g",
-	"XXx",
 };
 
-static const char FLASH_APP_FILE_EXT[CALC_MAX + 1][4] = 
+static const char FLASH_APP_FILE_EXT[NCALCS + 1][4] = 
 {
-	"XXx", 
-	"73k", "XXx", "XXx", "8Xk", "8Xk", "XXx", "XXx",
-	"89k", "89k", "XXx", "9Xk", "V2k", "8Xk", "89k",
-	"XXx",
+	"XxX", 
+	"73k", "???", "???", "8Xk", "8Xk", "???", "???",
+	"89k", "89k", "???", "9Xk", "V2k", "8Xk", "89k",
 };
 
-static const char FLASH_OS_FILE_EXT[CALC_MAX + 1][4] = 
+static const char FLASH_OS_FILE_EXT[NCALCS + 1][4] = 
 {
-	"XXx", 
-	"73u", "XXx", "XXx", "8Xu", "8Xu", "XXx", "XXx",
-	"89u", "89u", "XXx", "9Xu", "V2u", "8Xu", "89u",
-	"tno",
+	"XxX", 
+	"73u", "???", "???", "8Xu", "8Xu", "???", "???",
+	"89u", "89u", "???", "9Xu", "V2u", "8Xu", "89u",
 };
 
-static const char CERTIF_FILE_EXT[CALC_MAX + 1][4] = 
+static const char CERTIF_FILE_EXT[NCALCS + 1][4] = 
 {
-	"XXx", 
-	"73q", "XXx", "XXx", "8Xq", "8Xq", "XXx", "XXx",
-	"89q", "89q", "XXx", "9Xq", "V2q", "8Xq", "89q",
-	"XXx",
+	"XxX", 
+	"73q", "???", "???", "8Xq", "8Xq", "???", "???",
+	"89q", "89q", "???", "9Xq", "V2q", "8Xq", "89q",
 };
 
 /*******************/
@@ -92,7 +89,7 @@ TIEXPORT2 const char *TICALL tifiles_fext_of_group (CalcModel model)
   switch (model) 
   {
   case CALC_NONE:
-    return "XXx";
+    return "??g";
   case CALC_TI73:
     return "73g";
   case CALC_TI82:
@@ -117,8 +114,6 @@ TIEXPORT2 const char *TICALL tifiles_fext_of_group (CalcModel model)
     return "9Xg";
   case CALC_V200:
     return "V2g";
-  case CALC_NSPIRE:
-	  return "XXx";
   default:
     tifiles_error("tifiles_fext_of_group: invalid calc_type argument.");
     break;
@@ -167,8 +162,6 @@ TIEXPORT2 const char *TICALL tifiles_fext_of_backup (CalcModel model)
 	return "8Xg";
   case CALC_TI89T_USB:
 	  return "89g";
-  case CALC_NSPIRE:
-	  return "XXx";
   default:
     tifiles_error("tifiles_fext_of_backup: invalid calc_type argument.");
     break;
@@ -194,29 +187,27 @@ TIEXPORT2 const char *TICALL tifiles_fext_of_flash_app (CalcModel model)
   case CALC_TI73:
     return "73k";
   case CALC_TI82:
-    return "XXx";
+    return "???";
   case CALC_TI83:
-    return "XXx";
+    return "???";
   case CALC_TI83P:
   case CALC_TI84P:
   case CALC_TI84P_USB:
     return "8Xk";
   case CALC_TI85:
-    return "XXx";
+    return "???";
   case CALC_TI86:
-    return "XXx";
+    return "???";
   case CALC_TI89:
   case CALC_TI89T:
   case CALC_TI89T_USB:
     return "89k";
   case CALC_TI92:
-    return "XXx";
+    return "???";
   case CALC_TI92P:
     return "9Xk";
   case CALC_V200:
     return "V2k";
-  case CALC_NSPIRE:
-	return "XXx";
   default:
     tifiles_error("tifiles_fext_of_flash_app: invalid calc_type argument.");
     break;
@@ -242,29 +233,27 @@ TIEXPORT2 const char *TICALL tifiles_fext_of_flash_os(CalcModel model)
   case CALC_TI73:
     return "73u";
   case CALC_TI82:
-    return "XXx";
+    return "???";
   case CALC_TI83:
-    return "XXx";
+    return "???";
   case CALC_TI83P:
   case CALC_TI84P:
   case CALC_TI84P_USB:
     return "8Xu";
   case CALC_TI85:
-    return "XXx";
+    return "???";
   case CALC_TI86:
-    return "XXx";
+    return "???";
   case CALC_TI89:
   case CALC_TI89T:
   case CALC_TI89T_USB:
     return "89u";
   case CALC_TI92:
-    return "XXx";
+    return "???";
   case CALC_TI92P:
     return "9Xu";
   case CALC_V200:
     return "V2u";
-  case CALC_NSPIRE:
-	return "tno";
   default:
     tifiles_error("tifiles_fext_of_flash_os: invalid calc_type argument.");
     break;
@@ -290,29 +279,27 @@ TIEXPORT2 const char *TICALL tifiles_fext_of_certif(CalcModel model)
   case CALC_TI73:
     return "73q";
   case CALC_TI82:
-    return "XXx";
+    return "???";
   case CALC_TI83:
-    return "XXx";
+    return "???";
   case CALC_TI83P:
   case CALC_TI84P:
   case CALC_TI84P_USB:
     return "8Xq";
   case CALC_TI85:
-    return "XXx";
+    return "???";
   case CALC_TI86:
-    return "XXx";
+    return "???";
   case CALC_TI89:
   case CALC_TI89T:
   case CALC_TI89T_USB:
     return "89q";
   case CALC_TI92:
-    return "XXx";
+    return "???";
   case CALC_TI92P:
     return "9Xq";
   case CALC_V200:
     return "V2q";
-  case CALC_NSPIRE:
-	return "XXx";
   default:
     tifiles_error("tifiles_fext_of_flash_os: invalid calc_type argument.");
     break;
@@ -351,136 +338,7 @@ TIEXPORT2 char *TICALL tifiles_fext_get(const char *filename)
  **/
 TIEXPORT2 char *TICALL tifiles_fext_dup(const char *filename)
 {
-    return g_strdup(tifiles_fext_get(filename));
-}
-
-/**********************/
-/* Signature checking */
-/**********************/
-
-static int tifiles_file_has_ti_header(const char *filename)
-{
-	FILE *f;
-	char buf[9];
-	char *p;
-
-	f = gfopen(filename, "rb");
-	if (f == NULL)
-		return 0;
-	
-	fread_8_chars(f, buf);
-	for(p = buf; *p != '\0'; p++)
-		*p = toupper(*p);
-
-	if (!strcmp(buf, "**TI73**") || !strcmp(buf, "**TI82**") ||
-      !strcmp(buf, "**TI83**") || !strcmp(buf, "**TI83F*") ||
-      !strcmp(buf, "**TI85**") || !strcmp(buf, "**TI86**") ||
-      !strcmp(buf, "**TI89**") || !strcmp(buf, "**TI92**") ||
-      !strcmp(buf, "**TI92P*") || !strcmp(buf, "**V200**") ||
-      !strcmp(buf, "**TIFL**")) {
-		fclose(f);
-		return !0;
-	}
-
-	if(!strncmp(buf, "*TI", 3))
-	{
-		fclose(f);
-		return !0;
-	}
-
-
-	fclose(f);
-	return 0;
-}
-
-#define TIB_SIGNATURE	"Advanced Mathematics Software"
-
-static int tifiles_file_has_tib_header(const char *filename)
-{
-	FILE *f;
-	char str[128];
-	char *e = tifiles_fext_get(filename);
-
-	if (!strcmp(e, ""))
-	  return 0;
-
-	if(g_ascii_strcasecmp(e, "tib"))
-		return 0;
-
-	f = gfopen(filename, "rb");
-	if(f == NULL)
-		return 0;
-
-	fread_n_chars(f, 22, str);
-	fread_n_chars(f, strlen(TIB_SIGNATURE), str);
-	str[strlen(TIB_SIGNATURE)] = '\0';
-	if(!strcmp(str, TIB_SIGNATURE)) 
-	{
-		fclose(f);
-		return !0;
-	}
-
-	return 0;
-}
-
-#define TIG_SIGNATURE	"PK\x03\x04"	// 0x04034b50
-#define TIG_SIGNATURE2	"PK\x05\x06"	// 0x06054b50
-
-static int tifiles_file_has_tig_header(const char *filename)
-{
-	FILE *f;
-	char str[5];
-	char *e = tifiles_fext_get(filename);
-
-	if (!strcmp(e, ""))
-	  return 0;
-
-	if(g_ascii_strcasecmp(e, "tig"))
-		return 0;
-
-	f = gfopen(filename, "rb");
-	if(f == NULL)
-		return 0;
-
-	fread_n_chars(f, strlen(TIG_SIGNATURE), str);
-	str[strlen(TIG_SIGNATURE)] = '\0';
-	if(!strcmp(str, TIG_SIGNATURE) || !strcmp(str, TIG_SIGNATURE2)) 
-	{
-		fclose(f);
-		return !0;
-	}
-
-	fclose(f);
-	return 0;
-}
-
-#define TNO_SIGNATURE	"TI-Nspire.tno "
-#define TNC_SIGNATURE	"TI-Nspire.tnc "
-
-TIEXPORT2 int TICALL tifiles_file_has_tno_header(const char *filename)
-{
-	FILE *f;
-	char str[128];
-	char *e = tifiles_fext_get(filename);
-
-	if (!strcmp(e, ""))
-	  return 0;
-
-	if(g_ascii_strcasecmp(e, "tno")	&& g_ascii_strcasecmp(e, "tnc"))
-		return 0;
-
-	f = gfopen(filename, "rb");
-	if(f == NULL)
-		return 0;
-
-	fread_n_chars(f, 14, str);
-	if(!strcmp(str, TNO_SIGNATURE) || !strcmp(str, TNC_SIGNATURE)) 
-	{
-		fclose(f);
-		return !0;
-	}
-
-	return 0;
+    return strdup(tifiles_fext_get(filename));
 }
 
 /**************/
@@ -510,45 +368,6 @@ static int is_regfile(const char *filename)
 #endif
 }
 
-/**
- * tifiles_file_is_ti:
- * @filename: a filename as string.
- *
- * Check whether file is a TI file by checking the signature.
- *
- * Return value: a boolean value.
- **/
-TIEXPORT2 int TICALL tifiles_file_is_ti(const char *filename)
-{
-	// bug: check that file is not a FIFO
-	if (!is_regfile(filename))
-		return 0;
-
-	if(tifiles_file_has_ti_header(filename))
-		return !0;
-
-	if(tifiles_file_has_tib_header(filename))
-		return !0;
-
-	if(tifiles_file_has_tig_header(filename))
-		return !0;
-
-	if(tifiles_file_has_tno_header(filename))
-		return !0;
-
-	{
-		char *e = tifiles_fext_get(filename);
-
-		if (!strcmp(e, ""))
-			return 0;
-
-		if(!g_ascii_strcasecmp(e, "tns"))
-			return !0;
-	}
-
-	return 0;
-}
-
 /**
  * tifiles_file_is_single:
  * @filename: a filename as string.
@@ -565,6 +384,7 @@ TIEXPORT2 int TICALL tifiles_file_is_single(const char *filename)
   if (!tifiles_file_is_group(filename) &&
       !tifiles_file_is_backup(filename) &&
       !tifiles_file_is_flash(filename) &&
+	  !tifiles_file_is_tib(filename) &&
 	  !tifiles_file_is_tigroup(filename))
     return !0;
 
@@ -590,7 +410,7 @@ TIEXPORT2 int TICALL tifiles_file_is_group(const char *filename)
   if (!tifiles_file_is_ti(filename))
     return 0;
 
-  for (i = 1; i < CALC_MAX + 1; i++) 
+  for (i = 1; i < NCALCS + 1; i++) 
   {
     if (!g_ascii_strcasecmp(e, GROUP_FILE_EXT[i]))
       return !0;
@@ -635,7 +455,7 @@ TIEXPORT2 int TICALL tifiles_file_is_backup(const char *filename)
   if (!tifiles_file_is_ti(filename))
     return 0;
 
-  for (i = 1; i < CALC_MAX + 1; i++) 
+  for (i = 1; i < NCALCS + 1; i++) 
   {
     if (!g_ascii_strcasecmp(e, BACKUP_FILE_EXT[i]))
       return !0;
@@ -644,68 +464,6 @@ TIEXPORT2 int TICALL tifiles_file_is_backup(const char *filename)
   return 0;
 }
 
-/**
- * tifiles_file_is_os:
- * @filename: a filename as string.
- *
- * Check whether file is a FLASH OS file (tib or XXu)
- *
- * Return value: a boolean value.
- **/
-TIEXPORT2 int TICALL tifiles_file_is_os(const char *filename)
-{
-  int i;
-  char *e = tifiles_fext_get(filename);
-
-  if (!strcmp(e, ""))
-    return 0;
-
-  if (!tifiles_file_is_ti(filename))
-    return 0;
-
-  if(tifiles_file_is_tib(filename))
-	  return !0;
-
-  if(tifiles_file_is_tno(filename))
-	  return !0;
-
-  for (i = 1; i < CALC_MAX + 1; i++) 
-  {
-    if (!g_ascii_strcasecmp(e, FLASH_OS_FILE_EXT[i]))
-      return !0;
-  }
-
-  return 0;
-}
-
-/**
- * tifiles_file_is_app:
- * @filename: a filename as string.
- *
- * Check whether file is a FLASH app file
- *
- * Return value: a boolean value.
- **/
-TIEXPORT2 int TICALL tifiles_file_is_app(const char *filename)
-{
-  int i;
-  char *e = tifiles_fext_get(filename);
-
-  if (!strcmp(e, ""))
-    return 0;
-
-  if (!tifiles_file_is_ti(filename))
-    return 0;
-
-  for (i = 1; i < CALC_MAX + 1; i++) 
-  {
-    if (!g_ascii_strcasecmp(e, FLASH_APP_FILE_EXT[i]))
-      return !0;
-  }
-
-  return 0;
-}
-
 /**
  * tifiles_file_is_flash:
  * @filename: a filename as string.
@@ -716,9 +474,30 @@ TIEXPORT2 int TICALL tifiles_file_is_app(const char *filename)
  **/
 TIEXPORT2 int TICALL tifiles_file_is_flash(const char *filename)
 {
-  return tifiles_file_is_os(filename) || tifiles_file_is_app(filename);
+  int i;
+  char *e = tifiles_fext_get(filename);
+
+  if (!strcmp(e, ""))
+    return 0;
+
+  if (!tifiles_file_is_ti(filename))
+    return 0;
+
+  for (i = 1; i < NCALCS + 1; i++) 
+  {
+    if ((!g_ascii_strcasecmp(e, FLASH_APP_FILE_EXT[i])) ||
+	(!g_ascii_strcasecmp(e, FLASH_OS_FILE_EXT[i])) ||
+	(!g_ascii_strcasecmp(e, CERTIF_FILE_EXT[i])))
+      return !0;
+  }
+
+  return 0;
 }
 
+#define TIB_SIGNATURE	"Advanced Mathematics Software"
+#define TIG_SIGNATURE	"PK\x03\x04"	// 0x04034b50
+#define TIG_SIGNATURE2	"PK\x05\x06"	// 0x06054b50
+
 /**
  * tifiles_file_is_tib:
  * @filename: a filename as string.
@@ -729,7 +508,31 @@ TIEXPORT2 int TICALL tifiles_file_is_flash(const char *filename)
  **/
 TIEXPORT2 int TICALL tifiles_file_is_tib(const char *filename)
 {
-	return tifiles_file_has_tib_header(filename);
+	FILE *f;
+	char str[128];
+	char *e = tifiles_fext_get(filename);
+
+	if (!strcmp(e, ""))
+	  return 0;
+
+	if(g_ascii_strcasecmp(e, "tib"))
+		return 0;
+
+	f = gfopen(filename, "rb");
+	if(f == NULL)
+		return 0;
+
+	fread_n_chars(f, 22, str);
+	fread_n_chars(f, strlen(TIB_SIGNATURE), str);
+	str[strlen(TIB_SIGNATURE)] = '\0';
+	if(!strcmp(str, TIB_SIGNATURE)) 
+	{
+		fclose(f);
+		return !0;
+	}
+
+	fclose(f);
+	return 0;
 }
 
 /**
@@ -742,7 +545,30 @@ TIEXPORT2 int TICALL tifiles_file_is_tib(const char *filename)
  **/
 TIEXPORT2 int TICALL tifiles_file_is_tigroup(const char *filename)
 {
-	return tifiles_file_has_tig_header(filename);
+	FILE *f;
+	char str[5];
+	char *e = tifiles_fext_get(filename);
+
+	if (!strcmp(e, ""))
+	  return 0;
+
+	if(g_ascii_strcasecmp(e, "tig"))
+		return 0;
+
+	f = gfopen(filename, "rb");
+	if(f == NULL)
+		return 0;
+
+	fread_n_chars(f, strlen(TIG_SIGNATURE), str);
+	str[strlen(TIG_SIGNATURE)] = '\0';
+	if(!strcmp(str, TIG_SIGNATURE) || !strcmp(str, TIG_SIGNATURE2)) 
+	{
+		fclose(f);
+		return !0;
+	}
+
+	fclose(f);
+	return 0;
 }
 
 TIEXPORT2 int TICALL tifiles_file_is_tig(const char *filename)
@@ -750,155 +576,56 @@ TIEXPORT2 int TICALL tifiles_file_is_tig(const char *filename)
 	return tifiles_file_is_tigroup(filename);
 }
 
-TIEXPORT2 int TICALL tifiles_file_is_tno(const char *filename)
+static int tifiles_file_has_header(const char *filename)
 {
-	return tifiles_file_has_tno_header(filename);
+	FILE *f;
+	char buf[9];
+	char *p;
+
+	f = gfopen(filename, "rb");
+	if (f == NULL)
+		return 0;
+	
+	fread_8_chars(f, buf);
+	for(p = buf; *p != '\0'; p++)
+		*p = toupper(*p);
+
+	if (!strcmp(buf, "**TI73**") || !strcmp(buf, "**TI82**") ||
+      !strcmp(buf, "**TI83**") || !strcmp(buf, "**TI83F*") ||
+      !strcmp(buf, "**TI85**") || !strcmp(buf, "**TI86**") ||
+      !strcmp(buf, "**TI89**") || !strcmp(buf, "**TI92**") ||
+      !strcmp(buf, "**TI92P*") || !strcmp(buf, "**V200**") ||
+      !strcmp(buf, "**TIFL**")) {
+		fclose(f);
+		return !0;
+	}
+
+	fclose(f);
+	return 0;
 }
 
 /**
- * tifiles_file_test:
+ * tifiles_file_is_ti:
  * @filename: a filename as string.
- * @type: type to check
- * @target: hand-held model or CALC_NONE for no filtering
  *
- * Check whether #filename is a TI file of type #type useable on a #target model.
- * This function is a generic one which overwrap and extends the tifiles_file_is_* 
- * functions.
- *
- * This is a powerful function which allows checking of a specific file type for
- * a given target.
+ * Check whether file is a TI file by checking the signature.
  *
  * Return value: a boolean value.
  **/
-TIEXPORT2 int TICALL tifiles_file_test(const char *filename, FileClass type, CalcModel target)
+TIEXPORT2 int TICALL tifiles_file_is_ti(const char *filename)
 {
-	char *e = tifiles_fext_get(filename);
-
-	if (!tifiles_file_is_ti(filename))
+	// bug: check that file is not a FIFO
+	if (!is_regfile(filename))
 		return 0;
 
-	if (!strcmp(e, ""))
-		return 0;
+	if(tifiles_file_has_header(filename))
+		return !0;
 
-	if(target > CALC_MAX)
-	{
-		tifiles_error("tifiles_file_test: invalid target argument! This is a bug.");
-		return 0;
-	}
+	if(tifiles_file_is_tib(filename))
+		return !0;
 
-	if(type & TIFILE_SINGLE)
-	{
-		if(target && !g_ascii_strncasecmp(e, GROUP_FILE_EXT[target], 2))
-			return !0;
-		else
-			return tifiles_file_is_single(filename);
-	}
-	
-	if(type & TIFILE_GROUP)
-	{
-		if(target && !g_ascii_strcasecmp(e, GROUP_FILE_EXT[target]))
-			return !0;
-		else
-			return tifiles_file_is_group(filename);
-	}
-	
-	if(type & TIFILE_REGULAR)
-	{
-		return tifiles_file_test(filename, TIFILE_SINGLE, target) ||
-				tifiles_file_test(filename, TIFILE_GROUP, target);
-	}
-	
-	if(type & TIFILE_BACKUP)
-	{
-		if(target && !g_ascii_strcasecmp(e, BACKUP_FILE_EXT[target]))
-			return !0;
-		else
-			return tifiles_file_is_backup(filename);
-	}
-	
-	if(type & TIFILE_OS)
-	{
-		if(target && !g_ascii_strcasecmp(e, FLASH_OS_FILE_EXT[target]))
-			return !0;
-		else if(target && tifiles_file_is_tib(filename))
-		{
-			FILE *f;
-			uint8_t data[16];
-
-			f = gfopen(filename, "rb");
-			if(f == NULL)
-				return 0;
-
-			fread_n_chars(f, 16, (char *)data);
-			fclose(f);
-
-			switch(data[8])
-			{
-			case 1: if(target != CALC_TI92P) return 0;
-			case 3: if(target != CALC_TI89)  return 0;
-			case 8: if(target != CALC_V200)  return 0;
-			case 9: if(target != CALC_TI89T) return 0;
-			}
-
-			return !0;
-		}
-		else
-			return tifiles_file_is_os(filename);
-	}
-	
-	if(type & TIFILE_APP)
-	{
-		if(target && !g_ascii_strcasecmp(e, FLASH_APP_FILE_EXT[target]))
-			return !0;
-		else
-			return tifiles_file_is_app(filename);
-	}
-	
-	if(type & TIFILE_FLASH)
-	{
-		return tifiles_file_test(filename, TIFILE_OS, target) ||
-				tifiles_file_test(filename, TIFILE_APP, target);
-	}
-	
-	if(type & TIFILE_TIGROUP)
-	{
-		if(target)
-		{
-			// No easy/light way for this part: we have to load the whole file 
-			// and to parse the TigEntry structures.
-			TigContent *content;
-			int ret, ok=0;
-			int k;
-
-			if(!tifiles_file_has_tig_header(filename))
-				return 0;
-
-			content = tifiles_content_create_tigroup(CALC_NONE, 0);
-			ret = tifiles_file_read_tigroup(filename, content);
-			if(ret) return 0;
-
-			for (k = 0; k < content->n_apps; k++)
-			{
-				TigEntry *te = content->app_entries[k];
-
-				if(tifiles_calc_are_compat(te->content.regular->model, target))
-					ok++;
-			}
-
-			for (k = 0; k < content->n_vars; k++)
-			{
-				TigEntry *te = content->var_entries[k];
-
-				if(tifiles_calc_are_compat(te->content.regular->model, target))
-					ok++;
-			}
-
-			tifiles_content_delete_tigroup(content);
-			return ok;
-		}
-		else
-			return tifiles_file_is_tigroup(filename);
-	}
+	if(tifiles_file_is_tigroup(filename))
+		return !0;
 
 	return 0;
 }
@@ -920,7 +647,7 @@ TIEXPORT2 CalcModel TICALL tifiles_file_get_model(const char *filename)
 {
   char *ext = tifiles_fext_get(filename);
   int type = CALC_NONE;
-  char str[4];
+  char str[3];
 
   if (!strcmp(ext, ""))
     return CALC_NONE;
@@ -950,8 +677,6 @@ TIEXPORT2 CalcModel TICALL tifiles_file_get_model(const char *filename)
     type = CALC_V200;
   //else if (!g_ascii_strcasecmp(str, "tib"))
     //type = CALC_TI89;	// consider .tib as TI89
-  else if (!g_ascii_strcasecmp(str, "tn"))
-	  type = CALC_NSPIRE;
   else
     type = CALC_NONE;
 
@@ -1001,9 +726,6 @@ TIEXPORT2 const char *TICALL tifiles_file_get_type(const char *filename)
   if (!g_ascii_strcasecmp(ext, "tib"))
     return _("OS upgrade");
 
-  if(!g_ascii_strcasecmp(ext, "tno") || !g_ascii_strcasecmp(ext, "tnc"))
-	return _("OS upgrade");
-
   if (!tifiles_file_is_ti(filename))
     return "";
 
@@ -1055,8 +777,6 @@ TIEXPORT2 const char *TICALL tifiles_file_get_type(const char *filename)
   case CALC_V200:
     return v200_byte2desc(v200_fext2byte(ext));
 #endif
-  case CALC_NSPIRE:
-	  return nsp_byte2desc(nsp_fext2byte(ext));
   case CALC_NONE:
   default:
     return "";
@@ -1085,9 +805,6 @@ TIEXPORT2 const char *TICALL tifiles_file_get_icon(const char *filename)
   if (!g_ascii_strcasecmp(ext, "tib"))
     return "OS upgrade";
 
-  if (!g_ascii_strcasecmp(ext, "tno") || !g_ascii_strcasecmp(ext, "tnc"))
-    return "OS upgrade";
-
   if (!tifiles_file_is_ti(filename))
     return "";
 
@@ -1139,8 +856,6 @@ TIEXPORT2 const char *TICALL tifiles_file_get_icon(const char *filename)
   case CALC_V200:
     return v200_byte2icon(v200_fext2byte(ext));
 #endif
-  case CALC_NSPIRE:
-	  return nsp_byte2icon(nsp_fext2byte(ext));
   case CALC_NONE:
   default:
     return "";
