@@ -80,8 +80,6 @@ TIEXPORT2 int TICALL tifiles_calc_are_compat(CalcModel model, CalcModel ref)
 		return !0;
 	else if(tifiles_calc_is_ti9x(model) && tifiles_calc_is_ti9x(ref))
 		return !0;
-	else if((model == CALC_NSPIRE) && (ref == CALC_NSPIRE))
-		return !0;
 
 	return 0;
 }
@@ -98,8 +96,7 @@ TIEXPORT2 int TICALL tifiles_has_folder(CalcModel calc_type)
 {
   return ((calc_type == CALC_TI89) || (calc_type == CALC_TI89T) ||
 	  (calc_type == CALC_TI92) || (calc_type == CALC_TI92P) || 
-	  (calc_type == CALC_V200) || (calc_type == CALC_TI89T_USB) ||
-	  (calc_type == CALC_NSPIRE));
+	  (calc_type == CALC_V200) || (calc_type == CALC_TI89T_USB));
 }
 
 /**
@@ -116,8 +113,7 @@ TIEXPORT2 int TICALL tifiles_is_flash(CalcModel calc_type)
 	  (calc_type == CALC_TI84P) || (calc_type == CALC_TI84P_USB) || 
 	  (calc_type == CALC_TI89T) || (calc_type == CALC_TI89) || 
 	  (calc_type == CALC_TI92P) ||
-	  (calc_type == CALC_V200) || (calc_type == CALC_TI89T_USB) ||
-	  (calc_type == CALC_NSPIRE));
+	  (calc_type == CALC_V200) || (calc_type == CALC_TI89T_USB));
 }
 
 /**
@@ -232,13 +228,13 @@ char* TICALL tifiles_build_fullname(CalcModel model, char *full_name,
 	  strcat(full_name, varname);
     }
 	else
-	{
 		strcpy(full_name, varname);
-	}
   } 
   else
   {
 	  strcpy(full_name, varname);
+	  //strncpy(full_name, varname, 8);
+	  //full_name[8] = '\0';
   }
 
   return full_name;
@@ -266,13 +262,13 @@ TIEXPORT2 char* TICALL tifiles_build_filename(CalcModel model, const VarEntry *v
 		const char *part3;
 		char *tmp;
 		
-		part2 = ticonv_varname_to_filename(model, ve->name, ve->type);
+		part2 = ticonv_varname_to_filename(model, ve->name);
 		part3 = tifiles_vartype2fext(model, ve->type);
 
 		tmp = g_strconcat(part2, ".", part3, NULL);
 		g_free(part2);
 
-		filename = g_strdup(tmp);
+		filename = strdup(tmp);
 		g_free(tmp);
 	}
 	else
@@ -282,8 +278,8 @@ TIEXPORT2 char* TICALL tifiles_build_filename(CalcModel model, const VarEntry *v
 		const char *part3;
 		char *tmp;
 		
-		part1 = ticonv_varname_to_filename(model, ve->folder, -1);
-		part2 = ticonv_varname_to_filename(model, ve->name, ve->type);
+		part1 = ticonv_varname_to_filename(model, ve->folder);
+		part2 = ticonv_varname_to_filename(model, ve->name);
 		part3 = tifiles_vartype2fext(model, ve->type);
 
 		tmp = g_strconcat(part1, ".", part2, ".", part3, NULL);
