@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: tifiles.h 4264 2009-05-29 21:46:26Z roms $ */
+/* $Id: tifiles.h 3056 2006-11-06 17:12:50Z roms $ */
 
 /*  libTIFILES - file format library, a part of the TiLP project
  *  Copyright (C) 1999-2005  Romain Lievin
@@ -41,17 +41,17 @@
 /* Versioning */
 
 #ifdef __WIN32__
-# define LIBFILES_VERSION "1.1.2"
+# define LIBFILES_VERSION "1.0.0"
 #else
 # define LIBFILES_VERSION VERSION
 #endif
 
 /* Types */
 
-// TI-XX: up to 4*8 chars + 1, NSpire, up to 4*255 chars + 1
-#define FLDNAME_MAX		1024
-#define VARNAME_MAX		1024
-#define FULNAME_MAX		2048
+#define FLDNAME_MAX		33	// 4*8 + 1 (UTF-8)
+#define VARNAME_MAX		33	// idem
+#define FULNAME_MAX		66	// 4*8 + 1 + 4*8 + 1 (UTF-8)
+#define FILES_NCALCS	14	// # of supported calcs
 
 /**
  * CalcModel:
@@ -64,12 +64,10 @@ typedef enum
 	CALC_NONE = 0,
 	CALC_TI73, CALC_TI82, CALC_TI83, CALC_TI83P, CALC_TI84P, CALC_TI85, CALC_TI86,
 	CALC_TI89, CALC_TI89T, CALC_TI92, CALC_TI92P, CALC_V200,
-	CALC_TI84P_USB, CALC_TI89T_USB, CALC_NSPIRE, CALC_MAX
+	CALC_TI84P_USB, CALC_TI89T_USB,
 } CalcModel;
 #endif
 
-#define FILES_NCALCS	CALC_MAX	// # of supported calcs
-
 /**
  * FileAttr:
  *
@@ -88,7 +86,7 @@ typedef enum
 typedef enum 
 {
   TIFILE_SINGLE = 1, TIFILE_GROUP = 2, TIFILE_REGULAR = 3, TIFILE_BACKUP = 4, 
-  TIFILE_FLASH = 8, TIFILE_TIGROUP = 16, TIFILE_OS = 32, TIFILE_APP = 64,
+  TIFILE_FLASH = 8, TIFILE_TIGROUP = 16, 
 } FileClass;
 
 /**
@@ -156,15 +154,13 @@ typedef struct
  * - entries must be NULL-terminated. Parsing is based on this property.
  * - num_entries must be exact. Counting relies on this.
  *
- * Note: NSpire uses only one entry (no grouping support).
- *
  **/
 typedef struct 
 {
   CalcModel		model;
 
   char			default_folder[FLDNAME_MAX];	// TI9x only
-  char			comment[43];					// Ti8x: 42 max, Ti9x: 40 max
+  char			comment[43];	// Ti8x: 42 max, Ti9x: 40 max
 
   int			num_entries;
   VarEntry**	entries;
@@ -341,11 +337,8 @@ typedef struct
   char*				comment;
   int				comp_level;
 
-  TigEntry**		var_entries;
-  int				n_vars;
-
-  TigEntry**		app_entries;
-  int				n_apps;
+  int				num_entries;
+  TigEntry**		entries;
 
   CalcModel			model_dst;
 
@@ -401,14 +394,9 @@ extern "C" {
   TIEXPORT2 int TICALL tifiles_file_is_group (const char *filename);
   TIEXPORT2 int TICALL tifiles_file_is_regular (const char *filename);
   TIEXPORT2 int TICALL tifiles_file_is_backup (const char *filename);
-  TIEXPORT2 int TICALL tifiles_file_is_os(const char *filename);
-  TIEXPORT2 int TICALL tifiles_file_is_app(const char *filename);
-  TIEXPORT2 int TICALL tifiles_file_is_tib (const char *filename);
   TIEXPORT2 int TICALL tifiles_file_is_flash (const char *filename);
+  TIEXPORT2 int TICALL tifiles_file_is_tib (const char *filename);
   TIEXPORT2 int TICALL tifiles_file_is_tigroup (const char *filename);
-  TIEXPORT2 int TICALL tifiles_file_is_tno(const char *filename);
-  
-  TIEXPORT2 int TICALL tifiles_file_test(const char *filename, FileClass type, CalcModel target);
 
   TIEXPORT2 CalcModel TICALL tifiles_file_get_model (const char *filename);
   TIEXPORT2 FileClass TICALL tifiles_file_get_class (const char *filename);
@@ -474,9 +462,6 @@ extern "C" {
   TIEXPORT2 int TICALL tifiles_file_write_flash2(const char *filename, FlashContent *content, char **filename2);
   TIEXPORT2 int TICALL tifiles_file_display_flash(FlashContent *content);
 
-  TIEXPORT2 FileContent*  TICALL tifiles_content_dup_regular(FileContent *content);
-  TIEXPORT2 FlashContent* TICALL tifiles_content_dup_flash(FlashContent *content);
-
   TIEXPORT2 int TICALL tifiles_file_display(const char *filename);
 
   // grouped.c
@@ -520,12 +505,12 @@ extern "C" {
 
   // tigroup.c -> ve_fp.c
   TIEXPORT2 TigEntry* TICALL tifiles_te_create(const char *filename, FileClass type, CalcModel model);
-  TIEXPORT2 int		  TICALL tifiles_te_delete(TigEntry* entry);
+  TIEXPORT2 int		 TICALL tifiles_te_delete(TigEntry* entry);
 
   TIEXPORT2 TigEntry**	TICALL tifiles_te_create_array(int nelts);
   TIEXPORT2 TigEntry**	TICALL tifiles_te_resize_array(TigEntry**, int nelts);
-  TIEXPORT2 void		TICALL tifiles_te_delete_array(TigEntry**);
-  TIEXPORT2 int			TICALL tifiles_te_sizeof_array(TigEntry**);
+  TIEXPORT2 void			TICALL tifiles_te_delete_array(TigEntry**);
+  TIEXPORT2 void			TICALL tifiles_te_sizeof_array(TigEntry**, int*, int*);
 
   // comment.c
   TIEXPORT2 const char* TICALL tifiles_comment_set_single(void);
@@ -536,7 +521,7 @@ extern "C" {
   // ve_fp.c
   TIEXPORT2 VarEntry*	TICALL tifiles_ve_create(void);
   TIEXPORT2 VarEntry*	TICALL tifiles_ve_create_with_data(uint32_t size);
-  TIEXPORT2 void		TICALL tifiles_ve_delete(VarEntry*);
+  TIEXPORT2 void			TICALL tifiles_ve_delete(VarEntry*);
 
   TIEXPORT2 void*		tifiles_ve_alloc_data(size_t size);
   TIEXPORT2 VarEntry*	TICALL tifiles_ve_copy(VarEntry* dst, VarEntry* src);
@@ -544,19 +529,16 @@ extern "C" {
 
   TIEXPORT2 VarEntry**	TICALL tifiles_ve_create_array(int nelts);
   TIEXPORT2 VarEntry**	TICALL tifiles_ve_resize_array(VarEntry**, int nelts);
-  TIEXPORT2 void		TICALL tifiles_ve_delete_array(VarEntry**);
+  TIEXPORT2 void			TICALL tifiles_ve_delete_array(VarEntry**);
 
   TIEXPORT2 FlashPage*	TICALL tifiles_fp_create(void);
+  TIEXPORT2 FlashPage**	TICALL tifiles_fp_create_array(int nelts);
+
+  TIEXPORT2 void*		tifiles_fp_alloc_data(size_t size);
   TIEXPORT2 FlashPage*	TICALL tifiles_fp_create_with_data(uint32_t size);
-  TIEXPORT2 void		TICALL tifiles_fp_delete(FlashPage*);
 
-  TIEXPORT2 void*		TICALL tifiles_fp_alloc_data(size_t size);
-
-  TIEXPORT2 FlashPage**	TICALL tifiles_fp_create_array(int nelts);  
-  TIEXPORT2 void		TICALL tifiles_fp_delete_array(FlashPage**);
-
-  // undocumented
-  TIEXPORT2 int** tifiles_create_table_of_entries(FileContent *content, int *nfolders);
+  TIEXPORT2 void			TICALL tifiles_fp_delete(FlashPage*);
+  TIEXPORT2 void			TICALL tifiles_fp_delete_array(FlashPage**);
 
   /************************/
   /* Deprecated functions */
