@@ -37,9 +37,10 @@
 #include <stdlib.h>
 #include <string.h>
 
+#ifdef HAVE_LIBZ
 #include "minizip/zip.h"
 #include "minizip/unzip.h"
-
+#endif
 /*
 #ifdef WIN32
 # define USEWIN32IOAPI
@@ -55,8 +56,10 @@
 
 #define WRITEBUFFERSIZE (8192)
 
+#ifdef HAVE_LIBZ
 extern uLong filetime(char *f, tm_zip *tmzip, uLong *dt);
 extern int do_list(unzFile uf);
+#endif
 
 #if !GLIB_CHECK_VERSION(2, 8, 0)
 #include <errno.h>
@@ -126,9 +129,9 @@ TIEXPORT2 TigEntry* TICALL tifiles_te_create(const char *filename, FileClass typ
 {
 	TigEntry *entry;
 
-	entry = (TigEntry *)g_malloc0(sizeof(TigEntry));
+	entry = (TigEntry *)calloc(1, sizeof(TigEntry));
 
-	entry->filename = g_strdup(g_basename(filename));
+	entry->filename = strdup(g_basename(filename));
 	entry->type = type;
 
 	if(type == TIFILE_FLASH)
@@ -149,14 +152,14 @@ TIEXPORT2 TigEntry* TICALL tifiles_te_create(const char *filename, FileClass typ
  **/
 TIEXPORT2 int TICALL tifiles_te_delete(TigEntry* entry)
 {
-	g_free(entry->filename);
+	free(entry->filename);
 
 	if(entry->type == TIFILE_FLASH)
 		tifiles_content_delete_flash(entry->content.flash);
 	else if(entry->type & TIFILE_REGULAR)
 		tifiles_content_delete_regular(entry->content.regular);
 
-	g_free(entry);
+	free(entry);
 	return 0;
 }
 
@@ -171,7 +174,7 @@ TIEXPORT2 int TICALL tifiles_te_delete(TigEntry* entry)
  **/
 TIEXPORT2 TigEntry**	TICALL tifiles_te_create_array(int nelts)
 {
-	return g_malloc0((nelts + 1) * sizeof(TigEntry *));
+	return calloc(nelts + 1, sizeof(TigEntry *));
 }
 
 /**
@@ -205,7 +208,7 @@ TIEXPORT2 void			TICALL tifiles_te_delete_array(TigEntry** array)
 
 	for(ptr = array; ptr; ptr++)
 		tifiles_te_delete(*ptr);
-	g_free(array);
+	free(array);
 }
 
 /**
@@ -218,14 +221,21 @@ TIEXPORT2 void			TICALL tifiles_te_delete_array(TigEntry** array)
  *
  * Return value: none.
  **/
-TIEXPORT2 int TICALL tifiles_te_sizeof_array(TigEntry** array)
+TIEXPORT2 void			TICALL tifiles_te_sizeof_array(TigEntry** array, int* r, int* f)
 {
-	int i;
+	int m, n;
 	TigEntry **p;
 
-	for(i = 0, p = array; *p; *p++, i++);
+	for(m = n = 0, p = array; *p; *p++)
+	{
+		if((*p)->type == TIFILE_FLASH)
+			n++;
+		else if((*p)->type & TIFILE_REGULAR)
+			m++;
+	}
 
-	return i;
+	*r = m;
+	*f = n;
 }
 
 // ---------------------------------------------------------------------------
@@ -242,32 +252,15 @@ TIEXPORT2 int TICALL tifiles_te_sizeof_array(TigEntry** array)
  **/
 TIEXPORT2 int TICALL tifiles_content_add_te(TigContent *content, TigEntry *te)
 {
-	if(te->type == TIFILE_FLASH)
-	{
-		int n = content->n_apps;
+	int n = content->num_entries;
 
-		content->app_entries = tifiles_te_resize_array(content->app_entries, n + 1);
+	content->entries = tifiles_te_resize_array(content->entries, n + 1);
 
-		content->app_entries[n++] = te;
-		content->app_entries[n] = NULL;
-		content->n_apps = n;
+	content->entries[n++] = te;
+	content->entries[n] = NULL;
+	content->num_entries = n;
 
-		return n;
-	}
-	else if(te->type & TIFILE_REGULAR)
-	{
-		int n = content->n_vars;
-
-		content->var_entries = tifiles_te_resize_array(content->var_entries, n + 1);
-
-		content->var_entries[n++] = te;
-		content->var_entries[n] = NULL;
-		content->n_vars = n;
-
-		return n;
-	}
-	
-	return 0;
+	return content->num_entries;
 }
 
 /**
@@ -281,65 +274,34 @@ TIEXPORT2 int TICALL tifiles_content_add_te(TigContent *content, TigEntry *te)
  **/
 TIEXPORT2 int TICALL tifiles_content_del_te(TigContent *content, TigEntry *te)
 {
-	int i, j, k;
+	int i, j;
 
 	// Search for entry
-	for(i = 0; i < content->n_vars && (te->type & TIFILE_REGULAR); i++)
+	for(i = 0; i < content->num_entries; i++)
 	{
-		TigEntry *s = content->var_entries[i];
-
-		if(!strcmp(s->filename, te->filename))
-			break;
-	}
-
-	for(j = 0; j < content->n_apps && (te->type & TIFILE_FLASH); j++)
-	{
-		TigEntry *s = content->app_entries[i];
+		TigEntry *s = content->entries[i];
 
 		if(!strcmp(s->filename, te->filename))
 			break;
 	}
 
 	// Not found ? Exit !
-	if((i == content->n_vars) && (j == content->n_apps))
+	if(i == content->num_entries)
 		return -1;
 
 	// Release
-	if(i < content->n_vars)
-	{
-		// Delete
-		tifiles_te_delete(content->var_entries[i]);
+	tifiles_te_delete(content->entries[i]);
 
-		// And shift
-		for(k = i; k < content->n_vars; k++)
-			content->var_entries[k] = content->var_entries[k+1];
-		content->var_entries[k] = NULL;
+	// And shift
+	for(j = i; j < content->num_entries; j++)
+		content->entries[j] = content->entries[j+1];
+	content->entries[j] = NULL;
 
-		// And resize
-		content->var_entries = tifiles_te_resize_array(content->var_entries, content->n_vars - 1);
-		content->n_vars--;
+	// And resize
+	content->entries = tifiles_te_resize_array(content->entries, content->num_entries - 1);
+	content->num_entries--;
 
-		return content->n_vars;
-	}
-
-	if(j < content->n_apps)
-	{
-		// Delete
-		tifiles_te_delete(content->app_entries[j]);
-
-		// And shift
-		for(k = j; k < content->n_apps; k++)
-			content->app_entries[k] = content->app_entries[k+1];
-		content->app_entries[k] = NULL;
-
-		// And resize
-		content->app_entries = tifiles_te_resize_array(content->app_entries, content->n_apps - 1);
-		content->n_apps--;
-
-		return content->n_apps;
-	}
-
-	return 0;
+	return content->num_entries;
 }
 
 #ifndef __WIN32__
@@ -484,7 +446,7 @@ TIEXPORT2 int TICALL tifiles_tigroup_contents(FileContent **src_contents1, Flash
 	{
 		for(i = 0; i < m; i++)
 		{
-			TigEntry *te = (TigEntry *)g_malloc0(sizeof(TigEntry));
+			TigEntry *te = (TigEntry *)calloc(1, sizeof(TigEntry));
 
 			te->filename = tifiles_build_filename(model, src_contents1[i]->entries[0]);
 			te->type = TIFILE_GROUP;
@@ -497,7 +459,7 @@ TIEXPORT2 int TICALL tifiles_tigroup_contents(FileContent **src_contents1, Flash
 	{
 		for(i = 0; i < n; i++)
 		{
-			TigEntry *te = (TigEntry *)g_malloc0(sizeof(TigEntry));
+			TigEntry *te = (TigEntry *)calloc(1, sizeof(TigEntry));
 			VarEntry ve;
 			FlashContent *ptr;
 
@@ -537,33 +499,35 @@ TIEXPORT2 int TICALL tifiles_untigroup_content(TigContent *src_content, FileCont
 	TigContent *src = src_content;
 	FileContent **dst1 = NULL;
 	FlashContent **dst2 = NULL;
-	int i, j;
+	int i, j, m, n, k;
 
 	// allocate an array of FileContent/FlashContent structures (NULL terminated)
+	tifiles_te_sizeof_array(src->entries, &m, &n);
+
 	{
-		dst1 = (FileContent **)g_malloc0((src->n_vars+1) * sizeof(FileContent *));
+		dst1 = (FileContent **)calloc(m+1, sizeof(FileContent *));
 		if (dst1 == NULL)
 			return ERR_MALLOC;
 	}
 	{
-		dst2 = (FlashContent **)g_malloc0((src->n_apps+1) * sizeof(FlashContent *));
+		dst2 = (FlashContent **)calloc(n+1, sizeof(FlashContent *));
 		if (dst2 == NULL)
 			return ERR_MALLOC;
 	}
 
-	// parse each entry and duplicate it into a single content
-	for(i = 0; i < src->n_vars; i++)
+	// parse each entry and duplicate it into a single content  
+	for (i = j = k = 0; k < src->num_entries; k++) 
 	{
-		TigEntry *te = src->var_entries[i];
+		TigEntry *te = src->entries[k];
 
-		dst1[i] = tifiles_content_dup_regular(te->content.regular);
-	}
-
-	for(j = 0; j < src->n_apps; j++)
-	{
-		TigEntry *te = src->app_entries[j];
-
-		dst2[j] = tifiles_content_dup_flash(te->content.flash);
+		if(te->type == TIFILE_FLASH)
+		{
+			dst2[j++] = tifiles_content_dup_flash(te->content.flash);
+		}
+		else if(te->type & TIFILE_REGULAR)
+		{
+			dst1[i++] = tifiles_content_dup_regular(te->content.regular);
+		}
 	}
 
 	*dst_contents1 = dst1;
@@ -601,11 +565,11 @@ TIEXPORT2 int TICALL tifiles_tigroup_files(char **src_filenames, const char *dst
 	model = tifiles_file_get_model(src_filenames[0]);
 
 	// allocate space for that
-	src1 = (FileContent **)g_malloc0((m + 1) * sizeof(FileContent *));
+	src1 = (FileContent **) calloc(m + 1, sizeof(FileContent *));
 	if (src1 == NULL)
 		return ERR_MALLOC;
 
-	src2 = (FlashContent **)g_malloc0((n + 1) * sizeof(FlashContent *));
+	src2 = (FlashContent **) calloc(n + 1, sizeof(FlashContent *));
 	if (src2 == NULL)
 		return ERR_MALLOC;
 
@@ -635,11 +599,11 @@ TIEXPORT2 int TICALL tifiles_tigroup_files(char **src_filenames, const char *dst
 
 tgf:
 	for(i = 0; i < m; i++)
-		g_free(src1[i]);
-	g_free(src1);
+		free(src1[i]);
+	free(src1);
 	for(i = 0; i < n; i++)
-		g_free(src2[i]);
-	g_free(src2);
+		free(src2[i]);
+	free(src2);
 	tifiles_content_delete_tigroup(dst);
 
 	return ret;
@@ -665,7 +629,7 @@ TIEXPORT2 int TICALL tifiles_untigroup_file(const char *src_filename, char ***ds
 	FileContent **ptr1, **dst1 = NULL;
 	FlashContent **ptr2, **dst2 = NULL;
 	char *real_name;
-	int i, j;
+	int i, m, n;
 	int ret = 0;
 
 	// read TiGroup file
@@ -678,11 +642,13 @@ TIEXPORT2 int TICALL tifiles_untigroup_file(const char *src_filename, char ***ds
 	if(ret) goto tuf;
 
 	// count number of structures and allocates array of strings
+	tifiles_te_sizeof_array(src->entries, &m, &n);
+	
 	if(dst_filenames != NULL)
-		*dst_filenames = (char **)g_malloc((src->n_vars + src->n_apps + 1) * sizeof(char *));
+		*dst_filenames = (char **)malloc((m + n + 1) * sizeof(char *));
 
 	// store each structure content to file
-	for (ptr1 = dst1, i = 0; *ptr1 != NULL || i < src->n_vars; ptr1++, i++)
+	for (ptr1 = dst1, i = 0; *ptr1 != NULL || i < m; ptr1++, i++)
 	{
 		ret = tifiles_file_write_regular(NULL, *ptr1, &real_name);
 		if(ret) goto tuf;
@@ -690,18 +656,18 @@ TIEXPORT2 int TICALL tifiles_untigroup_file(const char *src_filename, char ***ds
 		if(dst_filenames != NULL)
 			*dst_filenames[i] = real_name;
 		else
-			g_free(real_name);
+			free(real_name);
 	}
 
-	for (ptr2 = dst2, j = 0; *ptr2 != NULL || j < src->n_apps; ptr2++, j++)
+	for (ptr2 = dst2; *ptr2 != NULL || i < m+n; ptr2++, i++)
 	{
 		ret = tifiles_file_write_flash2(NULL, *ptr2, &real_name);
 		if(ret) goto tuf;
 
 		if(dst_filenames != NULL)
-			*dst_filenames[i+j] = real_name;
+			*dst_filenames[i] = real_name;
 		else
-			g_free(real_name);
+			free(real_name);
 	}
 
 	// release allocated memory
@@ -735,13 +701,12 @@ tuf:
  **/
 TIEXPORT2 TigContent* TICALL tifiles_content_create_tigroup(CalcModel model, int n)
 {
-	TigContent* content = g_malloc0(sizeof(FileContent));
+	TigContent* content = calloc(1, sizeof(FileContent));
 
 	content->model = content->model_dst = model;
-	content->comment = g_strdup(tifiles_comment_set_tigroup());
-	content->comp_level = 4;
-	content->var_entries = (TigEntry **)g_malloc0(sizeof(TigEntry *));
-	content->app_entries = (TigEntry **)g_malloc0(sizeof(TigEntry *));
+	content->comment = strdup(tifiles_comment_set_tigroup());
+	content->comp_level = 0;
+	content->entries = (TigEntry **)calloc(n + 1, sizeof(TigEntry *));
 
 	return content;
 }
@@ -755,20 +720,18 @@ TIEXPORT2 TigContent* TICALL tifiles_content_create_tigroup(CalcModel model, int
  **/
 TIEXPORT2 int TICALL tifiles_content_delete_tigroup(TigContent *content)
 {
-	int i;
+	int i, n;
+	
+	// counter number of files to group
+	for(n = 0; content->entries[n]; n++);
 
-	for(i = 0; i < content->n_vars; i++)
+	// release allocated memory in structures
+	for (i = 0; i < n; i++) 
 	{
-		TigEntry* entry = content->var_entries[i];
+		TigEntry* entry = content->entries[i];
 		tifiles_te_delete(entry);
 	}
-
-	for(i = 0; i < content->n_apps; i++)
-	{
-		TigEntry* entry = content->app_entries[i];
-		tifiles_te_delete(entry);
-	}
-	g_free(content);
+	free(content);
 
 	return 0;
 }
@@ -786,6 +749,7 @@ TIEXPORT2 int TICALL tifiles_content_delete_tigroup(TigContent *content)
  **/
 TIEXPORT2 int TICALL tifiles_file_read_tigroup(const char *filename, TigContent *content)
 {
+#ifdef HAVE_LIBZ
 	unzFile uf = NULL;
 	unz_global_info gi;
 	unz_file_info file_info;
@@ -794,13 +758,13 @@ TIEXPORT2 int TICALL tifiles_file_read_tigroup(const char *filename, TigContent
 	unsigned i;
 	void* buf = NULL;
 	const char *password = NULL;
-	int vi = 0, ai = 0;
+	int ri = 0;
 
 	// Open ZIP archive
 	uf = unzOpen(filename);
 	if (uf == NULL)
 	{
-		printf("Can't open this file: %s\n", filename);
+		printf("Can't open this file: <%s>", filename);
 		return ERR_FILE_ZIP;
 	}
 
@@ -821,17 +785,13 @@ TIEXPORT2 int TICALL tifiles_file_read_tigroup(const char *filename, TigContent
 	}        
 	//printf("# entries: %lu\n", gi.number_entry);
 
-	g_free(content->var_entries);
-	content->var_entries = (TigEntry **)g_malloc0((gi.number_entry + 1) * sizeof(TigEntry *));
-	content->n_vars = 0;
-
-	g_free(content->app_entries);
-	content->app_entries = (TigEntry **)g_malloc0((gi.number_entry + 1) * sizeof(TigEntry *));
-	content->n_apps = 0;
+	free(content->entries);
+	content->entries = (TigEntry **)calloc(gi.number_entry + 1, sizeof(TigEntry *));
+	content->num_entries = 0;
 
 	// Get comment
-	g_free(content->comment);
-	content->comment = (char *)g_malloc((gi.size_comment+1) * sizeof(char));
+	free(content->comment);
+	content->comment = (char *)malloc((gi.size_comment+1) * sizeof(char));
 	err = unzGetGlobalComment(uf, content->comment, gi.size_comment);
 
 	// Parse archive for files
@@ -849,7 +809,7 @@ TIEXPORT2 int TICALL tifiles_file_read_tigroup(const char *filename, TigContent
 			printf("error %d with zipfile in unzGetCurrentFileInfo\n",err);
 			goto tfrt_exit;
 		}
-		//printf("Extracting %s with %lu bytes\n", filename_inzip, file_info.uncompressed_size);
+		//printf("Extracting <%s> with %lu bytes\n", filename_inzip, file_info.uncompressed_size);
 
 		err = unzOpenCurrentFilePassword(uf,password);
         if (err!=UNZ_OK)
@@ -898,32 +858,29 @@ TIEXPORT2 int TICALL tifiles_file_read_tigroup(const char *filename, TigContent
 
 		// add to TigContent
 		{
-			int model = tifiles_file_get_model(fname);
-
-			if(content->model == CALC_NONE)
-				content->model = model;
+			content->model = tifiles_file_get_model(fname);
 
 			if(tifiles_file_is_regular(fname))
 			{
-				TigEntry *entry = tifiles_te_create(filename_inzip, tifiles_file_get_class(fname), content->model);
+				TigEntry *entry = tifiles_te_create(filename_inzip, tifiles_file_get_class(fname), tifiles_file_get_model(fname));
 				int ret;
 
 				ret = tifiles_file_read_regular(fname, entry->content.regular);
-				if(ret) { g_free(entry); unlink(fname); g_free(fname); err = ret; goto tfrt_exit; }
+				if(ret) { free(entry); unlink(fname); g_free(fname); err = ret; goto tfrt_exit; }
 
-				content->var_entries[vi++] = entry;
-				content->n_vars++;
+				content->entries[ri++] = entry;
+				content->num_entries++;
 			}
 			else if(tifiles_file_is_flash(fname))
 			{
-				TigEntry *entry = tifiles_te_create(filename_inzip, tifiles_file_get_class(fname), content->model);
+				TigEntry *entry = tifiles_te_create(filename_inzip, tifiles_file_get_class(fname), tifiles_file_get_model(fname));
 				int ret;
 
 				ret = tifiles_file_read_flash(fname, entry->content.flash);
-				if(ret) { g_free(entry); unlink(fname); g_free(fname); err = ret; goto tfrt_exit; }
+				if(ret) { free(entry); unlink(fname); g_free(fname); err = ret; goto tfrt_exit; }
 
-				content->app_entries[ai++] = entry;
-				content->n_apps++;
+				content->entries[ri++] = entry;
+				content->num_entries++;
 			}
 			else
 			{
@@ -947,38 +904,92 @@ TIEXPORT2 int TICALL tifiles_file_read_tigroup(const char *filename, TigContent
 
 	// Close
 tfrt_exit:
-	g_free(buf);
+	free(buf);
 	unzCloseCurrentFile(uf);
 	return err ? ERR_FILE_ZIP : 0;
+#else
+	return ERR_UNSUPPORTED;
+#endif
 }
 
-static int zip_write(zipFile *zf, const char *fname, int comp_level)
+/**
+ * tifiles_file_write_tigroup:
+ * @filename: the name of file to load.
+ * @content: where to store content.
+ *
+ * This function store TiGroup contents to file. Please note that contents 
+ * can contains no data. In this case, the file is void but created.
+ *
+ * The temporary folder is used by this function to store temporary files.
+ *
+ * Return value: an error code if unsuccessful, 0 otherwise.
+ **/
+TIEXPORT2 int TICALL tifiles_file_write_tigroup(const char *filename, TigContent *content)
 {
-		int err = ZIP_OK;
-		FILE *f = NULL;
-		zip_fileinfo zi;
+#ifdef HAVE_LIBZ
+	zipFile zf;
+	zip_fileinfo zi;
+	int err = ZIP_OK;
+    void* buf=NULL;
+	gchar *old_dir = g_get_current_dir();
+	TigEntry **ptr;
+
+	// Open ZIP archive (and set comment)
+#ifdef USEWIN32IOAPI
+        zlib_filefunc_def ffunc;
+        fill_win32_filefunc(&ffunc);
+
+        zf = zipOpen2(filename, APPEND_STATUS_CREATE, &(content->comment), &ffunc);
+#else
+        zf = zipOpen(filename, APPEND_STATUS_CREATE);
+#endif
+	if (zf == NULL)
+	{
+		printf("Can't open this file: <%s>", filename);
+		return ERR_FILE_ZIP;
+	}
+	g_chdir(g_get_tmp_dir());
+
+	// Allocate buffer
+	buf = (void*)malloc(WRITEBUFFERSIZE);
+	if (buf==NULL)
+	{
+		printf("Error allocating memory\n");
+		goto tfwt_exit;
+	}
+
+	// Parse entries and store
+	for(ptr = content->entries; *ptr; ptr++)
+	{
+		FILE *f;
 		char filenameinzip[256];
 		unsigned long crcFile=0;
 		int size_read;
-		void* buf=NULL;
+		TigEntry* entry = *ptr;
+		char *fname = NULL;
+
+		// ZIP archives don't like greek chars
+		fname = ticonv_gfe_to_zfe(content->model, entry->filename);
+
+		// write TI file into tmp folder
+		if(entry->type == TIFILE_FLASH)
+		{
+			TRYC(tifiles_file_write_flash(fname, entry->content.flash));
+		}
+		else
+		{	
+			TRYC(tifiles_file_write_regular(fname, entry->content.regular, NULL));
+		}
 
 		// missing tmp file !
 		f = gfopen(fname, "rb");
 		if(f == NULL)
 		{
-		  printf("error in opening tmp file %s\n", fname);
 			err = ERR_FILE_OPEN;
-			goto zw_exit;
+			goto tfwt_exit;
 		}
 		strcpy(filenameinzip, fname);
-
-		// Allocate buffer
-		buf = (void*)g_malloc(WRITEBUFFERSIZE);
-		if (buf==NULL)
-		{
-			printf("Error allocating memory\n");
-			goto zw_exit;
-		}
+		g_free(fname);
 
 		// update time stamp (to do ?)
 		zi.tmz_date.tm_sec = zi.tmz_date.tm_min = zi.tmz_date.tm_hour =
@@ -988,9 +999,9 @@ static int zip_write(zipFile *zf, const char *fname, int comp_level)
         zi.external_fa = 0;
         filetime(filenameinzip,&zi.tmz_date,&zi.dosDate);
 
-		err = zipOpenNewFileInZip3(*zf,filenameinzip,&zi,
+		err = zipOpenNewFileInZip3(zf,filenameinzip,&zi,
                                  NULL,0,NULL,0,NULL /* comment*/,
-                                 comp_level ? Z_DEFLATED : 0 /* comp method */,
+                                 content->comp_level ? Z_DEFLATED : 0 /* comp method */,
                                  1 /*comp level */,0,
                                  -MAX_WBITS, DEF_MEM_LEVEL, Z_DEFAULT_STRATEGY,
                                  NULL /* no pwd*/,crcFile);
@@ -1012,117 +1023,44 @@ static int zip_write(zipFile *zf, const char *fname, int comp_level)
 				{
 					printf("error in reading %s\n",filenameinzip);
 					err = ZIP_ERRNO;
-					goto zw_exit;
+					goto tfwt_exit;
 				}
 			}
             if (size_read > 0)
             {
-                err = zipWriteInFileInZip (*zf,buf,size_read);
+                err = zipWriteInFileInZip (zf,buf,size_read);
                 if (err<0)
                 {
                     printf("error in writing %s in the zipfile\n", filenameinzip);
-					goto zw_exit;
+					goto tfwt_exit;
                 }
 
             }
         } while ((err == ZIP_OK) && (size_read>0));
 
 		// close file
-		err = zipCloseFileInZip(*zf);
+		err = zipCloseFileInZip(zf);
         if (err!=ZIP_OK)
 		{
             printf("error in closing %s in the zipfile\n", filenameinzip);
-			goto zw_exit;
+			goto tfwt_exit;
 		}
 
-zw_exit:
-		g_free(buf);
 		fclose(f);
-		return err;
-}
-
-/**
- * tifiles_file_write_tigroup:
- * @filename: the name of file to load.
- * @content: where to store content.
- *
- * This function store TiGroup contents to file. Please note that contents 
- * can contains no data. In this case, the file is void but created.
- *
- * The temporary folder is used by this function to store temporary files.
- *
- * Return value: an error code if unsuccessful, 0 otherwise.
- **/
-TIEXPORT2 int TICALL tifiles_file_write_tigroup(const char *filename, TigContent *content)
-{
-	zipFile zf;
-	int err = ZIP_OK;
-	gchar *old_dir = g_get_current_dir();
-	TigEntry **ptr;
-
-	// Open ZIP archive (and set comment)
-#ifdef USEWIN32IOAPI
-        zlib_filefunc_def ffunc;
-        fill_win32_filefunc(&ffunc);
-
-        zf = zipOpen2(filename, APPEND_STATUS_CREATE, &(content->comment), &ffunc);
-#else
-        zf = zipOpen(filename, APPEND_STATUS_CREATE);
-#endif
-	if (zf == NULL)
-	{
-		printf("Can't open this file: %s\n", filename);
-		return ERR_FILE_ZIP;
-	}
-	g_chdir(g_get_tmp_dir());
-
-	// Parse entries and store
-	for(ptr = content->var_entries; *ptr; ptr++)
-	{
-		TigEntry* entry = *ptr;
-		char *fname = NULL;
-
-		// ZIP archives don't like greek chars
-		fname = ticonv_gfe_to_zfe(content->model, entry->filename);
-
-		// write TI file into tmp folder
-		TRYC(tifiles_file_write_regular(fname, entry->content.regular, NULL));
-
-		err = zip_write(&zf, fname, content->comp_level);
-		g_free(fname);
-
-		if(err)
-			break;
-	}
-
-	for(ptr = content->app_entries; *ptr; ptr++)
-	{
-		TigEntry* entry = *ptr;
-		char *fname = NULL;
-
-		// ZIP archives don't like greek chars
-		fname = ticonv_gfe_to_zfe(content->model, entry->filename);
-
-		// write TI file into tmp folder
-		TRYC(tifiles_file_write_flash(fname, entry->content.flash));
-
-		err = zip_write(&zf, fname, content->comp_level);
-		g_free(fname);
-
-		if(err)
-			break;
+		unlink(filename);
 	}
 
 	// close archive
+tfwt_exit:
 	err = zipClose(zf,NULL);
     if (err != ZIP_OK)
-    {
         printf("error in closing %s\n",filename);
-		unlink(filename);
-    }
-	
+	free(buf);
 	g_chdir(old_dir);
 	return err;
+#else
+	return ERR_UNSUPPORTED;
+#endif
 }
 
 /**
@@ -1135,12 +1073,13 @@ TIEXPORT2 int TICALL tifiles_file_write_tigroup(const char *filename, TigContent
  **/
 TIEXPORT2 int TICALL tifiles_file_display_tigroup(const char *filename)
 {
+#ifdef HAVE_LIBZ
 	unzFile uf = NULL;
 
 	uf = unzOpen(filename);
 	if (uf==NULL)
     {
-		tifiles_warning("Can't open this file: %s", filename);
+		tifiles_warning("Can't open this file: <%s>", filename);
 		return -1;
 	}
 
@@ -1148,4 +1087,7 @@ TIEXPORT2 int TICALL tifiles_file_display_tigroup(const char *filename)
 	unzCloseCurrentFile(uf);
 
 	return 0;
+#else
+	return ERR_UNSUPPORTED;
+#endif
 }
