@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: type2str.c 3881 2007-10-11 19:36:54Z roms $ */
+/* $Id: type2str.c 3056 2006-11-06 17:12:50Z roms $ */
 
 /*  libtifiles - file format library, a part of the TiLP project
  *  Copyright (C) 1999-2005  Romain Lievin
@@ -52,7 +52,6 @@ TIEXPORT2 const char *TICALL tifiles_model_to_string(CalcModel model)
   	case CALC_TI73:  return "TI73";
 	case CALC_TI84P_USB: return "TI84+ USB";
 	case CALC_TI89T_USB: return "TI89t USB";
-	case CALC_NSPIRE: return "NSpire";
   	default: return "unknown";
   	}
 }
@@ -95,10 +94,6 @@ TIEXPORT2 CalcModel TICALL tifiles_string_to_model(const char *str)
 		return CALC_TI84P_USB;
 	else if(!g_ascii_strcasecmp(str, "TI89t USB"))
 		return CALC_TI89T_USB;
-	else if(!g_ascii_strcasecmp(str, "NSpire"))
-		return CALC_NSPIRE;
-	else if(!g_ascii_strcasecmp(str, "NSpire"))
-		return CALC_NSPIRE;
 		
 	return CALC_NONE;
 }
@@ -159,12 +154,9 @@ TIEXPORT2 const char *TICALL tifiles_class_to_string(FileClass klass)
 	{
   	case TIFILE_SINGLE: return _("single");
   	case TIFILE_GROUP:  return _("group");
-	case TIFILE_REGULAR:return _("regular");
   	case TIFILE_BACKUP: return _("backup");
-	case TIFILE_TIGROUP:return _("tigroup");
-	case TIFILE_OS:		return _("os");
-	case TIFILE_APP:	return _("application");
   	case TIFILE_FLASH:  return _("flash");
+	case TIFILE_TIGROUP:  return _("tigroup");
   	default: return _("unknown");
   	}
 }
@@ -183,19 +175,12 @@ TIEXPORT2 FileClass TICALL tifiles_string_to_class(const char *str)
 		return TIFILE_SINGLE;
 	else if(!g_ascii_strcasecmp(str, _("group")))
 		return TIFILE_GROUP;
-	else if(!g_ascii_strcasecmp(str, _("regular")))
-		return TIFILE_REGULAR;
 	else if(!g_ascii_strcasecmp(str, _("backup")))
 		return TIFILE_BACKUP;
-	else if(!g_ascii_strcasecmp(str, _("os")))
-		return TIFILE_OS;
-	else if(!g_ascii_strcasecmp(str, _("application")))
-		return TIFILE_APP;
 	else if(!g_ascii_strcasecmp(str, _("flash")))
 		return TIFILE_FLASH;
 	else if(!g_ascii_strcasecmp(str, _("tigroup")))
 		return TIFILE_TIGROUP;
-	
 		
 	return TIFILE_SINGLE;
 }
