@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: types73.c 3514 2007-06-25 21:15:48Z roms $ */
+/* $Id: types73.c 3056 2006-11-06 17:12:50Z roms $ */
 
 /*  libtifiles - file format library, a part of the TiLP project
  *  Copyright (C) 1999-2005  Romain Lievin
@@ -53,9 +53,9 @@ const char *TI73_CONST[TI73_MAXTYPES + 1][4] =
   {"CPLX", "73c", "Complex", N_("Complex")},
   {"", "73?", "Unknown", N_("Unknown")},
   {"", "73?", "Unknown", N_("Unknown")},
-  {"WINDW", "73w", "Window", N_("Window Setup")},
+  {"WDW", "73w", "Window", N_("Window")},
   {"ZSTO", "73z", "Zoom", N_("Zoom")},
-  {"TABLE", "73t", "Table Setup", N_("Table Setup")},
+  {"TAB", "73t", "Table Setup", N_("Table Setup")},
   {"", "73?", "Unknown", N_("Unknown")},
   {"BKUP", "73b", "Backup", N_("Backup")},
   {"", "73?", "Unknown", N_("Unknown")},
@@ -64,7 +64,7 @@ const char *TI73_CONST[TI73_MAXTYPES + 1][4] =
   {"", "73?", "Unknown", N_("Unknown")},
   {"", "73?", "Unknown", N_("Unknown")},
   {"DIR", "73?", "Unknown", N_("Unknown")},
-  {"AVAR", "73v", "App Var", N_("App Var")},
+  {"", "73?", "Unknown", N_("Unknown")},
   {"", "73?", "Unknown", N_("Unknown")},
   {"", "73?", "Unknown", N_("Unknown")},
   {"", "73?", "Unknown", N_("Unknown")},
