@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: types82.c 3432 2007-06-16 15:11:42Z roms $ */
+/* $Id: types82.c 3056 2006-11-06 17:12:50Z roms $ */
 
 /*  libtifiles - file format library, a part of the TiLP project
  *  Copyright (C) 1999-2005  Romain Lievin
@@ -43,9 +43,9 @@ const char *TI82_CONST[TI82_MAXTYPES + 1][4] =
   {"GDB", "82d", "GDB", N_("GDB")},
   {"", "82?", "Unknown", N_("Unknown")},
   {"", "82?", "Unknown", N_("Unknown")},
-  {"WINDW", "82w", "Window Setup", N_("Window Setup")},
+  {"WDW", "82w", "Window Setup", N_("Window Setup")},
   {"ZSTO", "82z", "Zoom", N_("Zoom")},
-  {"TABLE", "82t", "Table Setup", N_("Table Setup")},
+  {"TAB", "82t", "Table Setup", N_("Table Setup")},
   {"LCD", "82?", "LCD", N_("LCD")},
   {"BKUP", "82b", "Backup", N_("Backup")},
   {"", "82?", "Unknown", N_("Unknown")},
