@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: types83.c 3431 2007-06-16 15:08:04Z roms $ */
+/* $Id: types83.c 3056 2006-11-06 17:12:50Z roms $ */
 
 /*  libtifiles - file format library, a part of the TiLP project
  *  Copyright (C) 1999-2005  Romain Lievin
@@ -45,11 +45,11 @@ const char *TI83_CONST[TI83_MAXTYPES + 1][4] =
   {"", "83?", "Unknown", N_("Unknown")},
   {"", "83?", "Unknown", N_("Unknown")},
   {"CPLX", "83c", "Complex", N_("Complex")},
-  {"", "83?", "Unknown", N_("Unknown")},
-  {"", "83?", "Unknown", N_("Unknown")},
-  {"WINDW", "83w", "Window", N_("Window Setup")},
   {"ZSTO", "83z", "Zoom", N_("Zoom")},
-  {"TABLE", "83t", "Table Setup", N_("Table Setup")},
+  {"TAB", "83t", "Table Setup", N_("Table Setup")},
+  {"", "83?", "Unknown", N_("Unknown")},
+  {"", "83?", "Unknown", N_("Unknown")},
+  {"", "83?", "Unknown", N_("Unknown")},
   {"", "83?", "Unknown", N_("Unknown")},
   {"BKUP", "83b", "Backup", N_("Backup")},
   {"", "83?", "Unknown", N_("Unknown")},
