@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: types83p.c 3786 2007-09-19 11:54:45Z roms $ */
+/* $Id: types83p.c 3056 2006-11-06 17:12:50Z roms $ */
 
 /*  libtifiles - file format library, a part of the TiLP project
  *  Copyright (C) 1999-2005  Romain Lievin
@@ -43,19 +43,19 @@ const char *TI83p_CONST[TI83p_MAXTYPES + 1][4] =
   {"GDB", "8Xg", "GDB", N_("GDB")},
   {"", "8X?", "Unknown", N_("Unknown")},
   {"", "8X?", "Unknown", N_("Unknown")},
-  {"WINDW", "8Xw", "Window Setup", N_("Window Setup")},
+  {"WDW", "8Xw", "Window", N_("Window")},
   {"CPLX", "8Xc", "Complex", N_("Complex")},
   {"", "8X?", "Unknown", N_("Unknown")},
   {"", "8X?", "Unknown", N_("Unknown")},
-  {"WINDW", "8Xw", "Window Setup", N_("Window Setup")},
+  {"WDW", "8Xw", "Window Setup", N_("Window Setup")},
   {"ZSTO", "8Xz", "Zoom", N_("Zoom")},
-  {"TABLE", "8Xt", "Table Setup", N_("Table Setup")},
+  {"TAB", "8Xt", "Table Setup", N_("Table Setup")},
   {"", "8X?", "Unknown", N_("Unknown")},
   {"BKUP", "8Xb", "Backup", N_("Backup")},
   {"", "8X?", "Unknown", N_("Unknown")},
   {"APPV", "8Xv", "App Var", N_("App Var")},
   {"", "8X?", "Unknown", N_("Unknown")},
-  {"GRP", "8Xgrp", "Group Var", N_("Group Var")},
+  {"GRP", "8X?", "Group Var", N_("Group Var")},
   {"", "8X?", "Unknown", N_("Unknown")},
   {"DIR", "8X?", "Unknown", N_("Unknown")},
   {"", "8X?", "Unknown", N_("Unknown")},
