@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: types86.c 3508 2007-06-25 19:57:30Z roms $ */
+/* $Id: types86.c 3056 2006-11-06 17:12:50Z roms $ */
 
 /*  libtifiles - file format library, a part of the TiLP project
  *  Copyright (C) 1999-2005  Romain Lievin
@@ -55,11 +55,11 @@ const char *TI86_CONST[TI86_MAXTYPES + 1][4] =
   {"SCRN", "86?", "Screen", N_("Screen")},
   {"DIR", "86?", "Directory", N_("Directory")},
   {"", "86?", "Unknown", N_("Unknown")},
-  {"WIND", "86w", "Func", N_("Window Setup")},
-  {"WIND", "86w", "Pol", N_("Window Setup")},
-  {"WIND", "86w", "Param", N_("Window Setup")},
-  {"WIND", "86w", "DifEq", N_("Window Setup")},
-  {"WIND", "86w", "ZRCL", N_("Window Setup")},
+  {"YVAR", "86y", "Y-Var", N_("Y-Var")},
+  {"POLAR", "86?", "Polar", N_("Polar")},
+  {"PARAM", "86?", "Parametric", N_("Parametric")},
+  {"DIFEQ", "86?", "Diff Equ", N_("Diff Equ")},
+  {"ZRCL", "86z", "Zoom", N_("Zoom")},
   {"", "86?", "Unknown", N_("Unknown")},
   {"BKUP", "86b", "Backup", N_("Backup")},
   {"", "86?", "Unknown", N_("Unknown")},
