@@ -1,6 +1,8 @@
-/*  libtifiles - TI File Format library
- *  Copyright (C) 2002-2003  Romain Lievin
- *
+/* Hey EMACS -*- linux-c -*- */
+/* $Id: types89.h 3056 2006-11-06 17:12:50Z roms $ */
+
+/*  libtifiles - file format library, a part of the TiLP project
+ *  Copyright (C) 1999-2005  Romain Lievin
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -19,7 +21,7 @@
 #ifndef __TIFILES_DEFS89__
 #define __TIFILES_DEFS89__
 
-#include "stdints.h"
+#include "stdints2.h"
 
 #define TI89_MAXTYPES 48
 
@@ -42,7 +44,8 @@
 #define TI89_BKUP 0x1D
 #define TI89_FDIR 0x1F		// full
 #define TI89_DIR  TI89_FDIR	//type
-#define TI89_ASM  0x21
+#define TI89_GETCERT 0x20
+#define TI89_ASM	 0x21
 #define TI89_IDLIST  0x22
 #define TI89_AMS     0x23
 #define TI89_APPL    0x24
