@@ -1,5 +1,8 @@
-/*  libtifiles - TI File Format library
- *  Copyright (C) 2002-2003  Romain Lievin
+/* Hey EMACS -*- linux-c -*- */
+/* $Id: typesv2.h 3056 2006-11-06 17:12:50Z roms $ */
+
+/*  libtifiles - file format library, a part of the TiLP project
+ *  Copyright (C) 1999-2005  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,7 +22,7 @@
 #ifndef __TIFILES_DEFSV2__
 #define __TIFILES_DEFSV2__
 
-#include "stdints.h"
+#include "stdints2.h"
 
 #define V200_MAXTYPES 48
 
@@ -42,7 +45,8 @@
 #define V200_BKUP 0x1D
 #define V200_FDIR 0x1F		// full
 #define V200_DIR  V200_FDIR	//type
-#define V200_ASM  0x21
+#define V200_GETCERT 0x20
+#define V200_ASM     0x21
 #define V200_IDLIST  0x22
 #define V200_AMS     0x23
 #define V200_APPL    0x24
